# -*- coding: utf-8 -*-

# Softbank-UTF8バイナリとemoji4unicodeのIDとのマッピング

# format("0x%03X", Rack::Ketai::Carrier::Softbank::Filter::EMOJI_TO_EMOJIID[[0xE001].pack('U*')])
#   => "0x19B" (男の子: Unicode E001)
# format("0x%03X", Rack::Ketai::Carrier::Softbank::Filter::EMOJI_TO_EMOJIID[[0xE04A, 0xE049].pack('U*')])
#   => "0x00F" (晴れときどきくもり = 晴れ+くもり : U+E04A+U+E049)

module Rack
  module Ketai
    module Carrier
      class Abstract
        class Filter
          EMOJI_DATA = {
            0xE13 => {:fallback=>"[\343\203\211\343\202\263\343\203\242\343\203\235\343\202\244\343\203\263\343\203\210]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-4", :google_code=>"FEE13"},
            0x4B3 => {:fallback=>nil, :unicode=>nil, :name=>"POST OFFICE", :google_code=>"FE4B3"},
            0x057 => {:fallback=>"[\343\203\241\343\203\255\343\203\263]", :unicode=>nil, :name=>"MELON", :google_code=>"FE057"},
            0x04C => {:fallback=>"[\346\240\227]", :unicode=>nil, :name=>"CHESTNUT", :google_code=>"FE04C"},
            0xE14 => {:fallback=>"[i\343\202\242\343\203\227\343\203\252]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-5", :google_code=>"FEE14"},
            0x4B4 => {:fallback=>nil, :unicode=>nil, :name=>"HOSPITAL", :google_code=>"FE4B4"},
            0x058 => {:fallback=>"[\343\203\221\343\202\244\343\203\212\343\203\203\343\203\227\343\203\253]", :unicode=>nil, :name=>"PINEAPPLE", :google_code=>"FE058"},
            0xE15 => {:fallback=>"[i\343\202\242\343\203\227\343\203\252]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-6", :google_code=>"FEE15"},
            0x4B5 => {:fallback=>nil, :unicode=>nil, :name=>"BANK", :google_code=>"FE4B5"},
            0x059 => {:fallback=>"[\343\203\226\343\203\211\343\202\246]", :unicode=>nil, :name=>"GRAPES", :google_code=>"FE059"},
            0x04D => {:fallback=>"[\350\212\261]", :unicode=>nil, :name=>"BLOSSOM", :google_code=>"FE04D"},
            0x190 => {:fallback=>nil, :unicode=>nil, :name=>"EYES", :google_code=>"FE190"},
            0xE16 => {:fallback=>"[\343\201\264]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-7", :google_code=>"FEE16"},
            0x4B6 => {:fallback=>nil, :unicode=>nil, :name=>"ATM", :google_code=>"FE4B6"},
            0x04E => {:fallback=>nil, :unicode=>nil, :name=>"HERB", :google_code=>"FE04E"},
            0x191 => {:fallback=>nil, :unicode=>nil, :name=>"EAR", :google_code=>"FE191"},
            0xE17 => {:fallback=>"[\343\201\202]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-8", :google_code=>"FEE17"},
            0x4B7 => {:fallback=>nil, :unicode=>nil, :name=>"HOTEL", :google_code=>"FE4B7"},
            0x04F => {:fallback=>"[\343\201\225\343\201\217\343\202\211\343\202\223\343\201\274]", :unicode=>nil, :name=>"CHERRIES", :google_code=>"FE04F"},
            0x192 => {:fallback=>"[\351\274\273]", :unicode=>nil, :name=>"NOSE", :google_code=>"FE192"},
            0xE18 => {:fallback=>"[\343\203\201\343\202\261\343\203\203\343\203\210]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-9", :google_code=>"FEE18"},
            0x4B8 => {:fallback=>nil, :unicode=>nil, :name=>"LOVE HOTEL", :google_code=>"FE4B8"},
            0x193 => {:fallback=>nil, :unicode=>nil, :name=>"MOUTH", :google_code=>"FE193"},
            0xE19 => {:fallback=>"[\343\203\201\343\202\261\343\203\203\343\203\210]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-10", :google_code=>"FEE19"},
            0x4B9 => {:fallback=>nil, :unicode=>nil, :name=>"CONVENIENCE STORE", :google_code=>"FE4B9"},
            0x194 => {:fallback=>nil, :unicode=>nil, :name=>"TONGUE", :google_code=>"FE194"},
            0x195 => {:fallback=>nil, :unicode=>nil, :name=>"LIPSTICK", :google_code=>"FE195"},
            0x196 => {:fallback=>"[\343\203\236\343\203\213\343\202\255\343\203\245\343\202\242]", :unicode=>nil, :name=>"NAIL CARE", :google_code=>"FE196"},
            0xE20 => {:fallback=>"[\343\203\201\343\202\247\343\203\203\343\202\257]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-17", :google_code=>"FEE20"},
            0x4C0 => {:fallback=>"[\345\267\245\345\240\264]", :unicode=>nil, :name=>"FACTORY", :google_code=>"FE4C0"},
            0x197 => {:fallback=>"[\343\202\250\343\202\271\343\203\206]", :unicode=>nil, :name=>"FACE MASSAGE", :google_code=>"FE197"},
            0x05A => {:fallback=>"[\343\203\242\343\203\242]", :unicode=>nil, :name=>"PEACH", :google_code=>"FE05A"},
            0xE21 => {:fallback=>"[F]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-18", :google_code=>"FEE21"},
            0x4C1 => {:fallback=>nil, :unicode=>"2693", :name=>"ANCHOR", :google_code=>"FE4C1"},
            0x198 => {:fallback=>nil, :unicode=>nil, :name=>"HAIRCUT", :google_code=>"FE198"},
            0x05B => {:fallback=>nil, :unicode=>nil, :name=>"APPLE-2", :google_code=>"FE05B"},
            0xE22 => {:fallback=>"[D]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-19", :google_code=>"FEE22"},
            0x4C2 => {:fallback=>nil, :unicode=>nil, :name=>"IZAKAYA LANTERN", :google_code=>"FE4C2"},
            0x199 => {:fallback=>"[\345\272\212\345\261\213]", :unicode=>nil, :name=>"BARBER POLE", :google_code=>"FE199"},
            0xE23 => {:fallback=>"[S]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-20", :google_code=>"FEE23"},
            0x4C3 => {:fallback=>nil, :unicode=>nil, :name=>"MOUNT FUJI", :google_code=>"FE4C3"},
            0xE24 => {:fallback=>"[C]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-21", :google_code=>"FEE24"},
            0x4C4 => {:fallback=>"[\346\235\261\344\272\254\343\202\277\343\203\257\343\203\274]", :unicode=>nil, :name=>"TOKYO TOWER", :google_code=>"FE4C4"},
            0x4C5 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-64", :google_code=>"FE4C5"},
            0xE1A => {:fallback=>"[\351\233\273\350\251\261\345\205\210\350\241\214]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-11", :google_code=>"FEE1A"},
            0x4BA => {:fallback=>nil, :unicode=>nil, :name=>"SCHOOL", :google_code=>"FE4BA"},
            0xE25 => {:fallback=>"[R]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-22", :google_code=>"FEE25"},
            0xE1B => {:fallback=>"[P\343\202\263\343\203\274\343\203\211]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-12", :google_code=>"FEE1B"},
            0x4BB => {:fallback=>"[\346\225\231\344\274\232]", :unicode=>"*26EA", :name=>"CHURCH", :google_code=>"FE4BB"},
            0xE26 => {:fallback=>"\342\226\240", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-23", :google_code=>"FEE26"},
            0x4C6 => {:fallback=>nil, :unicode=>nil, :name=>"STATUE OF LIBERTY", :google_code=>"FE4C6"},
            0xE1C => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-13", :google_code=>"FEE1C"},
            0x4BC => {:fallback=>"[\345\231\264\346\260\264]", :unicode=>"*26F2", :name=>"FOUNTAIN", :google_code=>"FE4BC"},
            0xE27 => {:fallback=>"\342\226\240", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-24", :google_code=>"FEE27"},
            0x4C7 => {:fallback=>"[\345\234\260\345\233\263]", :unicode=>nil, :name=>"SKETCH OF JAPAN", :google_code=>"FE4C7"},
            0xE1D => {:fallback=>"[\343\201\264]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-14", :google_code=>"FEE1D"},
            0x4BD => {:fallback=>"[\343\203\207\343\203\221\343\203\274\343\203\210]", :unicode=>nil, :name=>"DEPARTMENT STORE", :google_code=>"FE4BD"},
            0xE28 => {:fallback=>"\342\226\274", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-25", :google_code=>"FEE28"},
            0x4C8 => {:fallback=>"[\343\203\242\343\202\242\343\202\244]", :unicode=>nil, :name=>"MOYAI", :google_code=>"FE4C8"},
            0xE1E => {:fallback=>"(\343\201\264)", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-15", :google_code=>"FEE1E"},
            0x4BE => {:fallback=>"[\345\237\216]", :unicode=>nil, :name=>"JAPANESE CASTLE", :google_code=>"FE4BE"},
            0xE29 => {:fallback=>"\342\200\240\342\200\240\342\200\240\342\200\240", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-26", :google_code=>"FEE29"},
            0x4C9 => {:fallback=>"[\343\203\254\343\203\263\343\203\201]", :unicode=>nil, :name=>"WRENCH", :google_code=>"FE4C9"},
            0xE1F => {:fallback=>"[\343\201\264]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-16", :google_code=>"FEE1F"},
            0x4BF => {:fallback=>"[\345\237\216]", :unicode=>nil, :name=>"WESTERN CASTLE", :google_code=>"FE4BF"},
            0xBA0 => {:fallback=>nil, :unicode=>nil, :name=>"THUMBS DOWN SIGN", :google_code=>"FEBA0"},
            0x19A => {:fallback=>nil, :unicode=>nil, :name=>"SILHOUETTE OF BUST", :google_code=>"FE19A"},
            0xBA1 => {:fallback=>nil, :unicode=>nil, :name=>"OPEN HANDS", :google_code=>"FEBA1"},
            0x19B => {:fallback=>nil, :unicode=>nil, :name=>"BOYS HEAD", :google_code=>"FE19B"},
            0xE30 => {:fallback=>"[VE]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-33", :google_code=>"FEE30"},
            0x4D0 => {:fallback=>"[\343\202\270\343\203\274\343\203\263\343\202\272]", :unicode=>nil, :name=>"JEANS", :google_code=>"FE4D0"},
            0xBA2 => {:fallback=>"[\343\203\255\343\203\203\343\202\257\343\202\252\343\203\263]", :unicode=>nil, :name=>"ROCK ON", :google_code=>"FEBA2"},
            0x19C => {:fallback=>nil, :unicode=>nil, :name=>"GIRLS HEAD", :google_code=>"FE19C"},
            0xE31 => {:fallback=>"\342\227\217", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-34", :google_code=>"FEE31"},
            0x4D1 => {:fallback=>nil, :unicode=>nil, :name=>"CROWN", :google_code=>"FE4D1"},
            0xBA3 => {:fallback=>nil, :unicode=>nil, :name=>"BLACK ROUNDED SQUARE", :google_code=>">FEB64"},
            0xE32 => {:fallback=>"[\343\202\253\343\203\274\343\203\211\344\275\277\347\224\250\344\270\215\345\217\257]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-35", :google_code=>"FEE32"},
            0x4D2 => {:fallback=>nil, :unicode=>nil, :name=>"TRIDENT EMBLEM", :google_code=>"FE4D2"},
            0x19D => {:fallback=>nil, :unicode=>nil, :name=>"MANS HEAD", :google_code=>"FE19D"},
            0xE33 => {:fallback=>"[\343\203\201\343\202\247\343\203\203\343\202\257\343\203\234\343\203\203\343\202\257\343\202\271]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-36", :google_code=>"FEE33"},
            0x4D3 => {:fallback=>"[\343\203\215\343\202\257\343\202\277\343\202\244]", :unicode=>nil, :name=>"NECKTIE", :google_code=>"FE4D3"},
            0x19E => {:fallback=>nil, :unicode=>nil, :name=>"WOMANS HEAD", :google_code=>"FE19E"},
            0x4D4 => {:fallback=>"[\345\270\275\345\255\220]", :unicode=>nil, :name=>"WOMANS HAT", :google_code=>"FE4D4"},
            0x19F => {:fallback=>"[\345\256\266\346\227\217]", :unicode=>nil, :name=>"FAMILY", :google_code=>"FE19F"},
            0x4D5 => {:fallback=>"[\343\203\211\343\203\254\343\202\271]", :unicode=>nil, :name=>"DRESS", :google_code=>"FE4D5"},
            0xE2A => {:fallback=>"\342\200\240\342\200\240\342\200\240", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-27", :google_code=>"FEE2A"},
            0x4CA => {:fallback=>"[\343\203\217\343\203\263\343\203\236\343\203\274]", :unicode=>nil, :name=>"HAMMER", :google_code=>"FE4CA"},
            0x500 => {:fallback=>nil, :unicode=>nil, :name=>"BOOK-2", :google_code=>"FE500"},
            0x4D6 => {:fallback=>nil, :unicode=>nil, :name=>"HIGH-HEELED SHOE", :google_code=>"FE4D6"},
            0xE2B => {:fallback=>"\342\200\240\342\200\240", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-28", :google_code=>"FEE2B"},
            0x4CB => {:fallback=>"[\343\203\215\343\202\270]", :unicode=>nil, :name=>"NUT AND BOLT", :google_code=>"FE4CB"},
            0x501 => {:fallback=>nil, :unicode=>nil, :name=>"BOOK-3", :google_code=>"FE501"},
            0x4D7 => {:fallback=>nil, :unicode=>nil, :name=>"WOMANS SANDAL", :google_code=>"FE4D7"},
            0xE2C => {:fallback=>"\342\200\240", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-29", :google_code=>"FEE2C"},
            0x4CC => {:fallback=>nil, :unicode=>nil, :name=>"MANS SHOE", :google_code=>"FE4CC"},
            0x502 => {:fallback=>nil, :unicode=>nil, :name=>"VERTICAL CLOSED BOOK", :google_code=>"FE502"},
            0x4D8 => {:fallback=>"[\343\203\226\343\203\274\343\203\204]", :unicode=>nil, :name=>"WOMANS BOOTS", :google_code=>"FE4D8"},
            0xE2D => {:fallback=>"[I]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-30", :google_code=>"FEE2D"},
            0x4CD => {:fallback=>nil, :unicode=>nil, :name=>"SNEAKER", :google_code=>"FE4CD"},
            0x503 => {:fallback=>nil, :unicode=>nil, :name=>"BOOKS", :google_code=>"FE503"},
            0x4D9 => {:fallback=>"[\347\235\200\347\211\251]", :unicode=>nil, :name=>"KIMONO", :google_code=>"FE4D9"},
            0xE2E => {:fallback=>"[M]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-31", :google_code=>"FEE2E"},
            0x4CE => {:fallback=>"[\343\203\241\343\202\254\343\203\215]", :unicode=>nil, :name=>"GLASSES", :google_code=>"FE4CE"},
            0x504 => {:fallback=>"[\345\220\215\346\234\255]", :unicode=>nil, :name=>"NAME BADGE", :google_code=>"FE504"},
            0xE2F => {:fallback=>"[E]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-32", :google_code=>"FEE2F"},
            0x4CF => {:fallback=>nil, :unicode=>nil, :name=>"T-SHIRT", :google_code=>"FE4CF"},
            0x505 => {:fallback=>nil, :unicode=>nil, :name=>"BATH", :google_code=>"FE505"},
            0x4E0 => {:fallback=>nil, :unicode=>nil, :name=>"HEAVY DOLLAR SIGN", :google_code=>"FE4E0"},
            0x506 => {:fallback=>nil, :unicode=>nil, :name=>"RESTROOM", :google_code=>"FE506"},
            0xE40 => {:fallback=>"[EZ]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-37", :google_code=>"FEE40"},
            0x507 => {:fallback=>nil, :unicode=>nil, :name=>"TOILET", :google_code=>"FE507"},
            0xE41 => {:fallback=>"[ezplus]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-38", :google_code=>"FEE41"},
            0x4E1 => {:fallback=>"[\343\202\253\343\203\274\343\203\211]", :unicode=>nil, :name=>"CREDIT CARD", :google_code=>"FE4E1"},
            0x508 => {:fallback=>nil, :unicode=>nil, :name=>"WATER CLOSET", :google_code=>"FE508"},
            0xE42 => {:fallback=>"[EZ\343\203\212\343\203\223]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-39", :google_code=>"FEE42"},
            0x4E2 => {:fallback=>"\357\277\245", :unicode=>nil, :name=>"BILL WITH YEN SIGN", :google_code=>"FE4E2"},
            0x509 => {:fallback=>"[\346\263\250\345\260\204]", :unicode=>nil, :name=>"SYRINGE", :google_code=>"FE509"},
            0xE43 => {:fallback=>"[EZ\343\203\240\343\203\274\343\203\223\343\203\274]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-40", :google_code=>"FEE43"},
            0x4E3 => {:fallback=>nil, :unicode=>nil, :name=>"DOLLAR BILL", :google_code=>"FE4E3"},
            0xE44 => {:fallback=>"[C\343\203\241\343\203\274\343\203\253]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-41", :google_code=>"FEE44"},
            0x4E4 => {:fallback=>"[\351\243\233\343\202\223\343\201\247\343\201\204\343\201\217\343\201\212\351\207\221]", :unicode=>nil, :name=>"MONEY WITH WINGS", :google_code=>"FE4E4"},
            0xE45 => {:fallback=>"[Java]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-42", :google_code=>"FEE45"},
            0x4E5 => {:fallback=>"[\346\227\245\343\201\256\344\270\270]", :unicode=>nil, :name=>"EMOJI SYMBOL JP", :google_code=>"FE4E5"},
            0x4DA => {:fallback=>"[\343\203\223\343\202\255\343\203\213]", :unicode=>nil, :name=>"BIKINI", :google_code=>"FE4DA"},
            0x510 => {:fallback=>nil, :unicode=>nil, :name=>"WRAPPED PRESENT", :google_code=>"FE510"},
            0xE46 => {:fallback=>"[BREW]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-43", :google_code=>"FEE46"},
            0x4E6 => {:fallback=>"[USA]", :unicode=>nil, :name=>"EMOJI SYMBOL US", :google_code=>"FE4E6"},
            0x4DB => {:fallback=>nil, :unicode=>nil, :name=>"WOMANS CLOTHES", :google_code=>"FE4DB"},
            0x511 => {:fallback=>nil, :unicode=>nil, :name=>"BIRTHDAY CAKE", :google_code=>"FE511"},
            0xE47 => {:fallback=>"[EZ\347\235\200\343\201\206\343\201\237]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-44", :google_code=>"FEE47"},
            0x4E7 => {:fallback=>"[\343\203\225\343\203\251\343\203\263\343\202\271]", :unicode=>nil, :name=>"EMOJI SYMBOL FR", :google_code=>"FE4E7"},
            0x4DC => {:fallback=>"[\350\262\241\345\270\203]", :unicode=>nil, :name=>"PURSE", :google_code=>"FE4DC"},
            0x512 => {:fallback=>nil, :unicode=>nil, :name=>"CHRISTMAS TREE", :google_code=>"FE512"},
            0xE48 => {:fallback=>"[EZ\343\203\212\343\203\223]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-45", :google_code=>"FEE48"},
            0x4E8 => {:fallback=>"[\343\203\211\343\202\244\343\203\204]", :unicode=>nil, :name=>"EMOJI SYMBOL DE", :google_code=>"FE4E8"},
            0x4DD => {:fallback=>nil, :unicode=>nil, :name=>"MONEY BAG", :google_code=>"FE4DD"},
            0x513 => {:fallback=>"[\343\202\265\343\203\263\343\202\277]", :unicode=>nil, :name=>"SANTA CLAUS", :google_code=>"FE513"},
            0xE49 => {:fallback=>"[WIN]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-46", :google_code=>"FEE49"},
            0x4E9 => {:fallback=>"[\343\202\244\343\202\277\343\203\252\343\202\242]", :unicode=>nil, :name=>"EMOJI SYMBOL IT", :google_code=>"FE4E9"},
            0x4DE => {:fallback=>"[$\357\277\245]", :unicode=>nil, :name=>"CURRENCY EXCHANGE", :google_code=>"FE4DE"},
            0x514 => {:fallback=>"[\347\245\235\346\227\245]", :unicode=>nil, :name=>"CROSSED FLAGS", :google_code=>"FE514"},
            0x4DF => {:fallback=>"[\346\240\252\344\276\241]", :unicode=>nil, :name=>"CHART WITH UPWARDS TREND AND YEN SYMBOL", :google_code=>"FE4DF"},
            0x515 => {:fallback=>"[\350\212\261\347\201\253]", :unicode=>nil, :name=>"FIREWORKS", :google_code=>"FE515"},
            0x516 => {:fallback=>"[\351\242\250\350\210\271]", :unicode=>nil, :name=>"BALLOON", :google_code=>"FE516"},
            0x4F0 => {:fallback=>nil, :unicode=>nil, :name=>"HANDBAG", :google_code=>"FE4F0"},
            0x50A => {:fallback=>"[\350\226\254]", :unicode=>nil, :name=>"PILL", :google_code=>"FE50A"},
            0x517 => {:fallback=>"[\343\202\257\343\203\251\343\203\203\343\202\253\343\203\274]", :unicode=>nil, :name=>"PARTY POPPER", :google_code=>"FE517"},
            0x4F1 => {:fallback=>"[\343\201\265\343\201\217\343\202\215]", :unicode=>nil, :name=>"POUCH", :google_code=>"FE4F1"},
            0x50B => {:fallback=>"[A]", :unicode=>"+1F170", :name=>"NEGATIVE SQUARED LATIN CAPITAL LETTER A", :google_code=>"FE50B"},
            0x518 => {:fallback=>"[\351\226\200\346\235\276]", :unicode=>nil, :name=>"PINE DECORATION", :google_code=>"FE518"},
            0x50C => {:fallback=>"[B]", :unicode=>"+1F171", :name=>"NEGATIVE SQUARED LATIN CAPITAL LETTER B", :google_code=>"FE50C"},
            0x519 => {:fallback=>"[\343\201\262\343\201\252\347\245\255\343\202\212]", :unicode=>nil, :name=>"GIRLS DOLL FESTIVAL", :google_code=>"FE519"},
            0x4F2 => {:fallback=>nil, :unicode=>nil, :name=>"BELL", :google_code=>"FE4F2"},
            0x50D => {:fallback=>"[AB]", :unicode=>"+1F18E", :name=>"NEGATIVE SQUARED LATIN CAPITAL LETTER AB", :google_code=>"FE50D"},
            0x4F3 => {:fallback=>"[\343\203\211\343\202\242]", :unicode=>nil, :name=>"DOOR", :google_code=>"FE4F3"},
            0x50E => {:fallback=>"[O]", :unicode=>"+1F17E", :name=>"NEGATIVE SQUARED LATIN CAPITAL LETTER O", :google_code=>"FE50E"},
            0x4F4 => {:fallback=>"[\343\202\246\343\203\263\343\203\201]", :unicode=>nil, :name=>"DUNG", :google_code=>"FE4F4"},
            0x50F => {:fallback=>nil, :unicode=>"+", :name=>"RIBBON", :google_code=>"FE50F"},
            0x4EA => {:fallback=>"[\343\202\244\343\202\256\343\203\252\343\202\271]", :unicode=>nil, :name=>"EMOJI SYMBOL GB", :google_code=>"FE4EA"},
            0x520 => {:fallback=>"[\343\202\252\343\203\241\343\203\207\343\203\210\343\202\246]", :unicode=>nil, :name=>"CONFETTI BALL", :google_code=>"FE520"},
            0x4F5 => {:fallback=>"[\343\203\224\343\202\271\343\203\210\343\203\253]", :unicode=>nil, :name=>"PISTOL", :google_code=>"FE4F5"},
            0xE4A => {:fallback=>"[\343\203\227\343\203\254\343\203\237\343\202\242\343\203\240]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-47", :google_code=>"FEE4A"},
            0x4EB => {:fallback=>"[\343\202\271\343\203\232\343\202\244\343\203\263]", :unicode=>nil, :name=>"EMOJI SYMBOL ES", :google_code=>"FE4EB"},
            0x521 => {:fallback=>"[\344\270\203\345\244\225]", :unicode=>nil, :name=>"TANABATA TREE", :google_code=>"FE521"},
            0x4F6 => {:fallback=>"[\347\202\216]", :unicode=>nil, :name=>"FIRE", :google_code=>"FE4F6"},
            0x4EC => {:fallback=>"[\343\203\255\343\202\267\343\202\242]", :unicode=>nil, :name=>"EMOJI SYMBOL RU", :google_code=>"FE4EC"},
            0x522 => {:fallback=>"[\343\203\235\343\202\261\343\203\231\343\203\253]", :unicode=>nil, :name=>"PAGER", :google_code=>"FE522"},
            0x4F7 => {:fallback=>"[\345\215\240\343\201\204]", :unicode=>nil, :name=>"CRYSTAL BALL", :google_code=>"FE4F7"},
            0x4ED => {:fallback=>"[\344\270\255\345\233\275]", :unicode=>nil, :name=>"EMOJI SYMBOL CN", :google_code=>"FE4ED"},
            0x523 => {:fallback=>nil, :unicode=>"260E", :name=>"BLACK TELEPHONE", :google_code=>"FE523"},
            0x4F8 => {:fallback=>"[\345\215\240\343\201\204]", :unicode=>nil, :name=>"SIX POINTED STAR WITH MIDDLE DOT", :google_code=>"FE4F8"},
            0x4EE => {:fallback=>"[\351\237\223\345\233\275]", :unicode=>nil, :name=>"EMOJI SYMBOL KR", :google_code=>"FE4EE"},
            0x524 => {:fallback=>nil, :unicode=>nil, :name=>"TELEPHONE RECEIVER", :google_code=>"FE524"},
            0x4F9 => {:fallback=>nil, :unicode=>nil, :name=>"VIDEO CAMERA", :google_code=>"FE4F9"},
            0x4EF => {:fallback=>nil, :unicode=>nil, :name=>"CAMERA", :google_code=>"FE4EF"},
            0x525 => {:fallback=>nil, :unicode=>nil, :name=>"MOBILE PHONE", :google_code=>"FE525"},
            0x526 => {:fallback=>nil, :unicode=>nil, :name=>"PHONE WITH ARROW", :google_code=>"FE526"},
            0x51A => {:fallback=>"[\345\215\222\346\245\255\345\274\217]", :unicode=>nil, :name=>"GRADUATION CAP", :google_code=>"FE51A"},
            0x527 => {:fallback=>nil, :unicode=>nil, :name=>"MEMO", :google_code=>"FE527"},
            0x51B => {:fallback=>"[\343\203\251\343\203\263\343\203\211\343\202\273\343\203\253]", :unicode=>nil, :name=>"SCHOOL SATCHEL", :google_code=>"FE51B"},
            0x528 => {:fallback=>nil, :unicode=>nil, :name=>"FAX", :google_code=>"FE528"},
            0x51C => {:fallback=>"[\343\201\223\343\201\204\343\201\256\343\201\274\343\202\212]", :unicode=>nil, :name=>"CARP STREAMER", :google_code=>"FE51C"},
            0x529 => {:fallback=>nil, :unicode=>"2709", :name=>"ENVELOPE", :google_code=>"FE529"},
            0x51D => {:fallback=>"[\347\267\232\351\246\231\350\212\261\347\201\253]", :unicode=>nil, :name=>"FIREWORK SPARKLER", :google_code=>"FE51D"},
            0x51E => {:fallback=>"[\351\242\250\351\210\264]", :unicode=>nil, :name=>"WIND CHIME", :google_code=>"FE51E"},
            0x51F => {:fallback=>"[\343\203\217\343\203\255\343\202\246\343\202\243\343\203\263]", :unicode=>nil, :name=>"JACK O LANTERN", :google_code=>"FE51F"},
            0x4FA => {:fallback=>"[\345\214\205\344\270\201]", :unicode=>nil, :name=>"KNIFE", :google_code=>"FE4FA"},
            0x530 => {:fallback=>"[\343\202\271\343\203\224\343\203\274\343\202\253]", :unicode=>nil, :name=>"CHEERING MEGAPHONE", :google_code=>"FE530"},
            0x4FB => {:fallback=>"[\346\207\220\344\270\255\351\233\273\347\201\257]", :unicode=>nil, :name=>"FLASHLIGHT", :google_code=>"FE4FB"},
            0x531 => {:fallback=>"[\343\202\242\343\203\263\343\203\206\343\203\212]", :unicode=>nil, :name=>"SATELLITE ANTENNA", :google_code=>"FE531"},
            0x4FC => {:fallback=>"[\351\233\273\346\261\240]", :unicode=>nil, :name=>"BATTERY", :google_code=>"FE4FC"},
            0x532 => {:fallback=>"[\343\203\225\343\202\255\343\203\200\343\202\267]", :unicode=>nil, :name=>"DIALOG BUBBLE", :google_code=>"FE532"},
            0x4FD => {:fallback=>"[\343\202\271\343\202\257\343\203\255\343\203\274\343\203\253]", :unicode=>nil, :name=>"SCROLL", :google_code=>"FE4FD"},
            0x533 => {:fallback=>"[\351\200\201\344\277\241BOX]", :unicode=>nil, :name=>"OUTBOX TRAY", :google_code=>"FE533"},
            0x4FE => {:fallback=>"[\343\202\263\343\203\263\343\202\273\343\203\263\343\203\210]", :unicode=>nil, :name=>"ELECTRIC PLUG", :google_code=>"FE4FE"},
            0x534 => {:fallback=>"[\345\217\227\344\277\241BOX]", :unicode=>nil, :name=>"INBOX TRAY", :google_code=>"FE534"},
            0x4FF => {:fallback=>nil, :unicode=>nil, :name=>"BOOK-1", :google_code=>"FE4FF"},
            0x535 => {:fallback=>nil, :unicode=>nil, :name=>"PACKAGE", :google_code=>"FE535"},
            0xE70 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-50", :google_code=>"FEE70"},
            0x52A => {:fallback=>nil, :unicode=>nil, :name=>"INCOMING ENVELOPE", :google_code=>"FE52A"},
            0x536 => {:fallback=>"[\343\203\232\343\203\263]", :unicode=>"2712", :name=>"BLACK NIB", :google_code=>"FE536"},
            0xE71 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-51", :google_code=>"FEE71"},
            0x52B => {:fallback=>nil, :unicode=>nil, :name=>"ENVELOPE WITH ARROW", :google_code=>"FE52B"},
            0x537 => {:fallback=>"[\343\201\204\343\201\231]", :unicode=>"+1F44D", :name=>"SEAT", :google_code=>"FE537"},
            0x52C => {:fallback=>nil, :unicode=>nil, :name=>"MAILBOX", :google_code=>"FE52C"},
            0x538 => {:fallback=>nil, :unicode=>nil, :name=>"COMPUTER", :google_code=>"FE538"},
            0xE72 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-52", :google_code=>"FEE72"},
            0x52D => {:fallback=>nil, :unicode=>nil, :name=>"MAILBOX WITH RAISED FLAG", :google_code=>"FE52D"},
            0x539 => {:fallback=>nil, :unicode=>"270F", :name=>"PENCIL", :google_code=>"FE539"},
            0xE73 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-53", :google_code=>"FEE73"},
            0x52E => {:fallback=>nil, :unicode=>nil, :name=>"POSTBOX", :google_code=>"FE52E"},
            0xE74 => {:fallback=>"[v", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-54", :google_code=>"FEE74"},
            0x52F => {:fallback=>"[\343\202\271\343\203\224\343\203\274\343\202\253]", :unicode=>nil, :name=>"PUBLIC ADDRESS LOUDSPEAKER", :google_code=>"FE52F"},
            0xE75 => {:fallback=>"oda", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-55", :google_code=>"FEE75"},
            0x540 => {:fallback=>nil, :unicode=>nil, :name=>"PAGE WITH CURL", :google_code=>"FE540"},
            0xE76 => {:fallback=>"fone]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-56", :google_code=>"FEE76"},
            0x541 => {:fallback=>nil, :unicode=>nil, :name=>"PAGE FACING UP", :google_code=>"FE541"},
            0xE77 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-57", :google_code=>"FEE77"},
            0x542 => {:fallback=>"[\343\202\253\343\203\254\343\203\263\343\203\200\343\203\274]", :unicode=>nil, :name=>"CALENDAR", :google_code=>"FE542"},
            0xE78 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-58", :google_code=>"FEE78"},
            0x543 => {:fallback=>"[\343\203\225\343\202\251\343\203\253\343\203\200]", :unicode=>nil, :name=>"FILE FOLDER", :google_code=>"FE543"},
            0xE79 => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-59", :google_code=>"FEE79"},
            0x544 => {:fallback=>"[\343\203\225\343\202\251\343\203\253\343\203\200]", :unicode=>nil, :name=>"OPEN FILE FOLDER", :google_code=>"FE544"},
            0x545 => {:fallback=>nil, :unicode=>nil, :name=>"NOTEBOOK", :google_code=>"FE545"},
            0x546 => {:fallback=>nil, :unicode=>nil, :name=>"OPEN BOOK", :google_code=>"FE546"},
            0x53A => {:fallback=>"[\343\202\257\343\203\252\343\203\203\343\203\227]", :unicode=>nil, :name=>"PAPERCLIP", :google_code=>"FE53A"},
            0x547 => {:fallback=>nil, :unicode=>nil, :name=>"NOTEBOOK WITH DECORATIVE COVER", :google_code=>"FE547"},
            0x53B => {:fallback=>nil, :unicode=>nil, :name=>"BRIEFCASE", :google_code=>"FE53B"},
            0x548 => {:fallback=>nil, :unicode=>nil, :name=>"CLIPBOARD", :google_code=>"FE548"},
            0x53C => {:fallback=>"[\343\203\225\343\203\255\343\203\203\343\203\224\343\203\274]", :unicode=>nil, :name=>"MINI DISC", :google_code=>"FE53C"},
            0x549 => {:fallback=>"[\343\202\253\343\203\254\343\203\263\343\203\200\343\203\274]", :unicode=>nil, :name=>"TEAR OFF CALENDAR", :google_code=>"FE549"},
            0x53D => {:fallback=>"[\343\203\225\343\203\255\343\203\203\343\203\224\343\203\274]", :unicode=>nil, :name=>"FLOPPY DISK", :google_code=>"FE53D"},
            0x53E => {:fallback=>nil, :unicode=>"2702", :name=>"BLACK SCISSORS", :google_code=>"FE53E"},
            0x53F => {:fallback=>"\317\206", :unicode=>nil, :name=>"ROUND PUSHPIN", :google_code=>"FE53F"},
            0xE7A => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-60", :google_code=>"FEE7A"},
            0x550 => {:fallback=>"[\345\256\232\350\246\217]", :unicode=>nil, :name=>"STRAIGHT RULER", :google_code=>"FE550"},
            0xE7B => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-61", :google_code=>"FEE7B"},
            0x551 => {:fallback=>"[\344\270\211\350\247\222\345\256\232\350\246\217]", :unicode=>nil, :name=>"TRIANGULAR RULER", :google_code=>"FE551"},
            0xE7C => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-62", :google_code=>"FEE7C"},
            0x552 => {:fallback=>nil, :unicode=>nil, :name=>"BOOKMARK TABS", :google_code=>"FE552"},
            0xE7D => {:fallback=>nil, :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-63", :google_code=>"FEE7D"},
            0x553 => {:fallback=>nil, :unicode=>nil, :name=>"FOOTPRINTS", :google_code=>"FE553"},
            0x54A => {:fallback=>"[\343\202\260\343\203\251\343\203\225]", :unicode=>nil, :name=>"BAR CHART", :google_code=>"FE54A"},
            0x54B => {:fallback=>"[\343\202\260\343\203\251\343\203\225]", :unicode=>nil, :name=>"CHART WITH UPWARDS TREND", :google_code=>"FE54B"},
            0x54C => {:fallback=>"[\343\202\260\343\203\251\343\203\225]", :unicode=>nil, :name=>"CHART WITH DOWNWARDS TREND", :google_code=>"FE54C"},
            0x54D => {:fallback=>nil, :unicode=>nil, :name=>"CARD INDEX", :google_code=>"FE54D"},
            0x54E => {:fallback=>"[\347\224\273\343\201\263\343\202\207\343\201\206]", :unicode=>nil, :name=>"PUSHPIN", :google_code=>"FE54E"},
            0x54F => {:fallback=>nil, :unicode=>nil, :name=>"LEDGER", :google_code=>"FE54F"},
            0xB00 => {:fallback=>"\342\226\274", :unicode=>nil, :name=>"DOWN-POINTING SMALL TRIANGLE-1", :google_code=>"FEB00"},
            0x1A0 => {:fallback=>nil, :unicode=>nil, :name=>"COUPLE", :google_code=>"FE1A0"},
            0xB01 => {:fallback=>"\342\226\262", :unicode=>nil, :name=>"UP-POINTING SMALL TRIANGLE-1", :google_code=>"FEB01"},
            0x1A1 => {:fallback=>"[\350\255\246\345\256\230]", :unicode=>nil, :name=>"POLICE OFFICER", :google_code=>"FE1A1"},
            0xB02 => {:fallback=>"\342\226\274", :unicode=>nil, :name=>"BLACK DOWN-POINTING DOUBLE TRIANGLE", :google_code=>"FEB02"},
            0x1A2 => {:fallback=>"[\343\203\220\343\203\213\343\203\274]", :unicode=>nil, :name=>"WOMAN WITH BUNNY EARS", :google_code=>"FE1A2"},
            0xB03 => {:fallback=>"\342\226\262", :unicode=>nil, :name=>"BLACK UP-POINTING DOUBLE TRIANGLE", :google_code=>"FEB03"},
            0x1A3 => {:fallback=>"[\350\212\261\345\253\201]", :unicode=>nil, :name=>"BRIDE WITH VEIL", :google_code=>"FE1A3"},
            0xB04 => {:fallback=>nil, :unicode=>"2762", :name=>"HEAVY EXCLAMATION MARK ORNAMENT", :google_code=>"FEB04"},
            0x1A4 => {:fallback=>"[\347\231\275\344\272\272]", :unicode=>nil, :name=>"WESTERN PERSON", :google_code=>"FE1A4"},
            0xB05 => {:fallback=>"\357\274\201\357\274\237", :unicode=>"2049", :name=>"EXCLAMATION QUESTION MARK", :google_code=>"FEB05"},
            0x1A5 => {:fallback=>"[\344\270\255\345\233\275\344\272\272]", :unicode=>nil, :name=>"MAN WITH GUA PI MAO", :google_code=>"FE1A5"},
            0xB06 => {:fallback=>"\357\274\201\357\274\201", :unicode=>"203C", :name=>"DOUBLE EXCLAMATION MARK", :google_code=>"FEB06"},
            0x1A6 => {:fallback=>"[\343\202\244\343\203\263\343\203\211]", :unicode=>nil, :name=>"MAN WITH TURBAN", :google_code=>"FE1A6"},
            0xB07 => {:fallback=>nil, :unicode=>"3030", :name=>"WAVY DASH", :google_code=>"FEB07"},
            0x1A7 => {:fallback=>"[\343\201\212\343\201\230\343\201\204\343\201\225\343\202\223]", :unicode=>nil, :name=>"OLDER MAN", :google_code=>"FE1A7"},
            0xB08 => {:fallback=>"\357\275\236", :unicode=>"+2E32", :name=>"LOOPED LENGTH MARK", :google_code=>"FEB08"},
            0x1A8 => {:fallback=>"[\343\201\212\343\201\260\343\201\202\343\201\225\343\202\223]", :unicode=>nil, :name=>"OLDER WOMAN", :google_code=>"FE1A8"},
            0xB09 => {:fallback=>"[\357\274\237]", :unicode=>nil, :name=>"BLACK QUESTION MARK ORNAMENT", :google_code=>"FEB09"},
            0x1A9 => {:fallback=>"[\350\265\244\343\201\241\343\202\203\343\202\223]", :unicode=>nil, :name=>"BABY", :google_code=>"FE1A9"},
            0x1B0 => {:fallback=>"[UFO]", :unicode=>nil, :name=>"EXTRATERRESTRIAL ALIEN", :google_code=>"FE1B0"},
            0xB10 => {:fallback=>nil, :unicode=>nil, :name=>"SPARKLING HEART", :google_code=>"FEB10"},
            0xB11 => {:fallback=>nil, :unicode=>nil, :name=>"GROWING HEART", :google_code=>"FEB11"},
            0x1B1 => {:fallback=>"[\345\256\207\345\256\231\344\272\272]", :unicode=>nil, :name=>"ALIEN MONSTER", :google_code=>"FE1B1"},
            0xB12 => {:fallback=>nil, :unicode=>nil, :name=>"HEART WITH ARROW", :google_code=>"FEB12"},
            0x1B2 => {:fallback=>"[\343\202\242\343\202\257\343\203\236]", :unicode=>nil, :name=>"IMP", :google_code=>"FE1B2"},
            0xB13 => {:fallback=>nil, :unicode=>nil, :name=>"HEART-1", :google_code=>"FEB13"},
            0x1B3 => {:fallback=>"[\343\203\211\343\202\257\343\203\255]", :unicode=>nil, :name=>"SKULL", :google_code=>"FE1B3"},
            0xB14 => {:fallback=>nil, :unicode=>nil, :name=>"HEART-2", :google_code=>"FEB14"},
            0x1B4 => {:fallback=>nil, :unicode=>nil, :name=>"INFORMATION DESK PERSON", :google_code=>"FE1B4"},
            0xB15 => {:fallback=>nil, :unicode=>nil, :name=>"HEART-3", :google_code=>"FEB15"},
            0x1B5 => {:fallback=>nil, :unicode=>nil, :name=>"GUARDSMAN", :google_code=>"FE1B5"},
            0xB0A => {:fallback=>"[\357\274\237]", :unicode=>nil, :name=>"WHITE QUESTION MARK ORNAMENT", :google_code=>"FEB0A"},
            0x1AA => {:fallback=>"[\345\267\245\344\272\213\347\217\276\345\240\264\343\201\256\344\272\272]", :unicode=>nil, :name=>"CONSTRUCTION WORKER", :google_code=>"FE1AA"},
            0xB16 => {:fallback=>nil, :unicode=>nil, :name=>"HEART-4", :google_code=>"FEB16"},
            0x1B6 => {:fallback=>"[\343\203\200\343\203\263\343\202\271]", :unicode=>nil, :name=>"DANCER", :google_code=>"FE1B6"},
            0xAF0 => {:fallback=>nil, :unicode=>"2197", :name=>"NORTH EAST ARROW", :google_code=>"FEAF0"},
            0xB0B => {:fallback=>nil, :unicode=>nil, :name=>"WHITE EXCLAMATION MARK ORNAMENT", :google_code=>"FEB0B"},
            0x1AB => {:fallback=>"[\343\201\212\345\247\253\346\247\230]", :unicode=>nil, :name=>"PRINCESS", :google_code=>"FE1AB"},
            0xB17 => {:fallback=>nil, :unicode=>nil, :name=>"HEART WITH RIBBON", :google_code=>"FEB17"},
            0x1B7 => {:fallback=>nil, :unicode=>nil, :name=>"DOG", :google_code=>"FE1B7"},
            0xAF1 => {:fallback=>nil, :unicode=>"2198", :name=>"SOUTH EAST ARROW", :google_code=>"FEAF1"},
            0xB0C => {:fallback=>nil, :unicode=>"2764", :name=>"HEAVY BLACK HEART", :google_code=>"FEB0C"},
            0x1AC => {:fallback=>"[\343\201\252\343\201\276\343\201\257\343\201\222]", :unicode=>nil, :name=>"OGRE", :google_code=>"FE1AC"},
            0xB18 => {:fallback=>nil, :unicode=>nil, :name=>"REVOLVING HEARTS", :google_code=>"FEB18"},
            0x1B8 => {:fallback=>nil, :unicode=>nil, :name=>"CAT", :google_code=>"FE1B8"},
            0xAF2 => {:fallback=>nil, :unicode=>"2196", :name=>"NORTH WEST ARROW", :google_code=>"FEAF2"},
            0xB0D => {:fallback=>nil, :unicode=>"+", :name=>"BEATING HEART", :google_code=>"FEB0D"},
            0x1AD => {:fallback=>"[\345\244\251\347\213\227]", :unicode=>nil, :name=>"GOBLIN", :google_code=>"FE1AD"},
            0xB19 => {:fallback=>nil, :unicode=>nil, :name=>"HEART DECORATION", :google_code=>"FEB19"},
            0x1B9 => {:fallback=>"[\343\202\253\343\202\277\343\203\204\343\203\240\343\203\252]", :unicode=>nil, :name=>"SNAIL", :google_code=>"FE1B9"},
            0xAF3 => {:fallback=>nil, :unicode=>"2199", :name=>"SOUTH WEST ARROW", :google_code=>"FEAF3"},
            0xB0E => {:fallback=>nil, :unicode=>nil, :name=>"BROKEN HEART", :google_code=>"FEB0E"},
            0x1AE => {:fallback=>"[\343\201\212\345\214\226\343\201\221]", :unicode=>nil, :name=>"GHOST", :google_code=>"FE1AE"},
            0xAF4 => {:fallback=>nil, :unicode=>"2934", :name=>"ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS", :google_code=>"FEAF4"},
            0xB0F => {:fallback=>nil, :unicode=>nil, :name=>"TWO HEARTS", :google_code=>"FEB0F"},
            0x1AF => {:fallback=>"[\345\244\251\344\275\277]", :unicode=>nil, :name=>"ANGEL", :google_code=>"FE1AF"},
            0x1C0 => {:fallback=>"[\343\203\210\343\203\251]", :unicode=>nil, :name=>"TIGER", :google_code=>"FE1C0"},
            0xAF5 => {:fallback=>nil, :unicode=>"2935", :name=>"ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS", :google_code=>"FEAF5"},
            0xB20 => {:fallback=>nil, :unicode=>"267F", :name=>"WHEELCHAIR SYMBOL", :google_code=>"FEB20"},
            0x1C1 => {:fallback=>"[\343\202\257\343\203\236]", :unicode=>nil, :name=>"BEAR", :google_code=>"FE1C1"},
            0xAF6 => {:fallback=>"\342\207\224", :unicode=>"2194", :name=>"LEFT RIGHT ARROW", :google_code=>"FEAF6"},
            0xB21 => {:fallback=>"[FREE]", :unicode=>nil, :name=>"FREE SIGN", :google_code=>"FEB21"},
            0xAF7 => {:fallback=>"\342\206\221\342\206\223", :unicode=>"2195", :name=>"UP DOWN ARROW", :google_code=>"FEAF7"},
            0xB22 => {:fallback=>"[\346\227\227]", :unicode=>nil, :name=>"TRIANGULAR FLAG ON POST", :google_code=>"FEB22"},
            0x1C2 => {:fallback=>"[\343\203\215\343\202\272\343\203\237]", :unicode=>nil, :name=>"MOUSE", :google_code=>"FE1C2"},
            0xAF8 => {:fallback=>"[\342\206\221]", :unicode=>"2B06", :name=>"UPWARDS BLACK ARROW", :google_code=>"FEAF8"},
            0xB23 => {:fallback=>nil, :unicode=>"26A0", :name=>"WARNING SIGN", :google_code=>"FEB23"},
            0x1C3 => {:fallback=>"[\343\202\257\343\202\270\343\203\251]", :unicode=>nil, :name=>"WHALE", :google_code=>"FE1C3"},
            0x320 => {:fallback=>nil, :unicode=>nil, :name=>"ANGRY FACE", :google_code=>"FE320"},
            0xAF9 => {:fallback=>"[\342\206\223]", :unicode=>"2B07", :name=>"DOWNWARDS BLACK ARROW", :google_code=>"FEAF9"},
            0xB24 => {:fallback=>"[\343\202\263\343\202\263]", :unicode=>"+1F201", :name=>"SQUARED KATAKANA KOKO", :google_code=>"FEB24"},
            0x1C4 => {:fallback=>nil, :unicode=>nil, :name=>"MONKEY FACE", :google_code=>"FE1C4"},
            0x321 => {:fallback=>nil, :unicode=>nil, :name=>"ANGUISHED FACE", :google_code=>"FE321"},
            0x1C5 => {:fallback=>"[\343\202\277\343\202\263]", :unicode=>nil, :name=>"OCTOPUS", :google_code=>"FE1C5"},
            0xB1A => {:fallback=>nil, :unicode=>"2665", :name=>"BLACK HEART SUIT", :google_code=>"FEB1A"},
            0x1BA => {:fallback=>nil, :unicode=>nil, :name=>"BABY CHICK", :google_code=>"FE1BA"},
            0x322 => {:fallback=>nil, :unicode=>nil, :name=>"ASTONISHED FACE", :google_code=>"FE322"},
            0xB25 => {:fallback=>"[18\347\246\201]", :unicode=>nil, :name=>"NO ONE UNDER EIGHTEEN SIGN", :google_code=>"FEB25"},
            0x1C6 => {:fallback=>"[\345\267\273\350\262\235]", :unicode=>nil, :name=>"SPIRAL SHELL", :google_code=>"FE1C6"},
            0xB1B => {:fallback=>nil, :unicode=>"2660", :name=>"BLACK SPADE SUIT", :google_code=>"FEB1B"},
            0x1BB => {:fallback=>nil, :unicode=>nil, :name=>"FRONT-FACING BABY CHICK", :google_code=>"FE1BB"},
            0x323 => {:fallback=>nil, :unicode=>nil, :name=>"DISAPPOINTED FACE", :google_code=>"FE323"},
            0xB26 => {:fallback=>nil, :unicode=>"26D4", :name=>"NO ENTRY", :google_code=>"FEB26"},
            0x1C7 => {:fallback=>"[\343\202\244\343\203\253\343\202\253]", :unicode=>nil, :name=>"DOLPHIN", :google_code=>"FE1C7"},
            0xB1C => {:fallback=>nil, :unicode=>"2666", :name=>"BLACK DIAMOND SUIT", :google_code=>"FEB1C"},
            0x1BC => {:fallback=>nil, :unicode=>nil, :name=>"PENGUIN", :google_code=>"FE1BC"},
            0x324 => {:fallback=>nil, :unicode=>nil, :name=>"DIZZY FACE", :google_code=>"FE324"},
            0xB27 => {:fallback=>nil, :unicode=>nil, :name=>"OK SIGN", :google_code=>"FEB27"},
            0x1C8 => {:fallback=>nil, :unicode=>nil, :name=>"BIRD", :google_code=>"FE1C8"},
            0xB1D => {:fallback=>nil, :unicode=>"2663", :name=>"BLACK CLUB SUIT", :google_code=>"FEB1D"},
            0x1BD => {:fallback=>nil, :unicode=>nil, :name=>"FISH", :google_code=>"FE1BD"},
            0x325 => {:fallback=>nil, :unicode=>nil, :name=>"EXASPERATED FACE", :google_code=>"FE325"},
            0xB28 => {:fallback=>"[NG]", :unicode=>nil, :name=>"NO GOOD SIGN", :google_code=>"FEB28"},
            0x1C9 => {:fallback=>nil, :unicode=>nil, :name=>"TROPICAL FISH", :google_code=>"FE1C9"},
            0xB1E => {:fallback=>nil, :unicode=>nil, :name=>"SMOKING SIGN", :google_code=>"FEB1E"},
            0x1BE => {:fallback=>nil, :unicode=>nil, :name=>"HORSE", :google_code=>"FE1BE"},
            0x326 => {:fallback=>nil, :unicode=>nil, :name=>"EXPRESSIONLESS FACE", :google_code=>"FE326"},
            0xB29 => {:fallback=>nil, :unicode=>"00A9", :name=>"COPYRIGHT SIGN", :google_code=>"FEB29"},
            0xB1F => {:fallback=>nil, :unicode=>nil, :name=>"NO SMOKING SIGN", :google_code=>"FEB1F"},
            0x1BF => {:fallback=>nil, :unicode=>nil, :name=>"PIG", :google_code=>"FE1BF"},
            0x327 => {:fallback=>nil, :unicode=>nil, :name=>"FACE WITH HEART SHAPED EYES", :google_code=>"FE327"},
            0x328 => {:fallback=>nil, :unicode=>nil, :name=>"FACE WITH LOOK OF TRIUMPH", :google_code=>"FE328"},
            0xAFA => {:fallback=>"[\342\206\222]", :unicode=>"27A1", :name=>"BLACK RIGHTWARDS ARROW", :google_code=>"FEAFA"},
            0xB30 => {:fallback=>"[\345\220\210]", :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-5408", :google_code=>"FEB30"},
            0x1D0 => {:fallback=>nil, :unicode=>nil, :name=>"WOLF", :google_code=>"FE1D0"},
            0x329 => {:fallback=>nil, :unicode=>nil, :name=>"WINKING FACE WITH STUCK OUT TONGUE", :google_code=>"FE329"},
            0xAFB => {:fallback=>"[\342\206\220]", :unicode=>"2B05", :name=>"LEFTWARDS BLACK ARROW", :google_code=>"FEAFB"},
            0x1D1 => {:fallback=>"[\347\211\233]", :unicode=>nil, :name=>"COW", :google_code=>"FE1D1"},
            0xAFC => {:fallback=>"[>]", :unicode=>"25B6", :name=>"BLACK RIGHT-POINTING TRIANGLE", :google_code=>"FEAFC"},
            0xB31 => {:fallback=>nil, :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-6E80", :google_code=>"FEB31"},
            0x1D2 => {:fallback=>"[\343\202\246\343\202\265\343\202\256]", :unicode=>nil, :name=>"RABBIT", :google_code=>"FE1D2"},
            0xAFD => {:fallback=>"[<]", :unicode=>"25C0", :name=>"BLACK LEFT-POINTING TRIANGLE", :google_code=>"FEAFD"},
            0xB32 => {:fallback=>"[VS]", :unicode=>nil, :name=>"VS SIGN", :google_code=>"FEB32"},
            0x330 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE WITH OPEN MOUTH", :google_code=>"FE330"},
            0xB33 => {:fallback=>"[\342\231\202]", :unicode=>nil, :name=>"MENS SYMBOL", :google_code=>"FEB33"},
            0x1D3 => {:fallback=>"[\343\203\230\343\203\223]", :unicode=>nil, :name=>"SNAKE", :google_code=>"FE1D3"},
            0x331 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE WITH OPEN MOUTH AND COLD SWEAT", :google_code=>"FE331"},
            0xAFE => {:fallback=>"[>>]", :unicode=>"+23EA", :name=>"BLACK RIGHT-POINTING DOUBLE TRIANGLE", :google_code=>"FEAFE"},
            0xB34 => {:fallback=>"[\342\231\200]", :unicode=>nil, :name=>"WOMENS SYMBOL", :google_code=>"FEB34"},
            0x1D4 => {:fallback=>"[\343\203\213\343\203\257\343\203\210\343\203\252]", :unicode=>nil, :name=>"CHICKEN", :google_code=>"FE1D4"},
            0x332 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE WITH OPEN MOUTH AND CLOSED EYES", :google_code=>"FE332"},
            0xAFF => {:fallback=>"[<<]", :unicode=>nil, :name=>"BLACK LEFT-POINTING DOUBLE TRIANGLE", :google_code=>"FEAFF"},
            0xB35 => {:fallback=>"[\350\265\244\343\201\241\343\202\203\343\202\223]", :unicode=>nil, :name=>"BABY SYMBOL", :google_code=>"FEB35"},
            0x1D5 => {:fallback=>"[\343\202\244\343\203\216\343\202\267\343\202\267]", :unicode=>nil, :name=>"BOAR", :google_code=>"FE1D5"},
            0xB2A => {:fallback=>nil, :unicode=>"2122", :name=>"TRADE MARK SIGN", :google_code=>"FEB2A"},
            0x1CA => {:fallback=>nil, :unicode=>nil, :name=>"HAMSTER", :google_code=>"FE1CA"},
            0x333 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE WITH GRIN", :google_code=>"FE333"},
            0xB36 => {:fallback=>nil, :unicode=>nil, :name=>"NEW SIGN", :google_code=>"FEB36"},
            0x1D6 => {:fallback=>"[\343\203\251\343\202\257\343\203\200]", :unicode=>nil, :name=>"CAMEL", :google_code=>"FE1D6"},
            0xB2B => {:fallback=>nil, :unicode=>"3299", :name=>"CIRCLED IDEOGRAPH SECRET", :google_code=>"FEB2B"},
            0x1CB => {:fallback=>"[\343\202\262\343\202\270\343\202\262\343\202\270]", :unicode=>nil, :name=>"BUG", :google_code=>"FE1CB"},
            0x334 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY AND CRYING FACE", :google_code=>"FE334"},
            0xB37 => {:fallback=>"[UP!]", :unicode=>nil, :name=>"UP SIGN", :google_code=>"FEB37"},
            0x1D7 => {:fallback=>"[\343\202\253\343\202\250\343\203\253]", :unicode=>nil, :name=>"FROG", :google_code=>"FE1D7"},
            0xB2C => {:fallback=>"\342\206\221\342\206\223", :unicode=>"267B", :name=>"BLACK UNIVERSAL RECYCLING SYMBOL", :google_code=>"FEB2C"},
            0x1CC => {:fallback=>"[\343\202\276\343\202\246]", :unicode=>nil, :name=>"ELEPHANT", :google_code=>"FE1CC"},
            0x335 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE WITH WIDE MOUTH AND RAISED EYEBROWS", :google_code=>"FE335"},
            0xB38 => {:fallback=>"[COOL]", :unicode=>nil, :name=>"COOL SIGN", :google_code=>"FEB38"},
            0x1D8 => {:fallback=>nil, :unicode=>nil, :name=>"POODLE", :google_code=>"FE1D8"},
            0xB2D => {:fallback=>nil, :unicode=>"00AE", :name=>"REGISTERED SIGN", :google_code=>"FEB2D"},
            0x1CD => {:fallback=>"[\343\202\263\343\202\242\343\203\251]", :unicode=>nil, :name=>"KOALA", :google_code=>"FE1CD"},
            0x336 => {:fallback=>nil, :unicode=>"263A", :name=>"WHITE SMILING FACE", :google_code=>"FE336"},
            0x32A => {:fallback=>nil, :unicode=>nil, :name=>"FACE WITH STUCK OUT TONGUE", :google_code=>"FE32A"},
            0xB39 => {:fallback=>"[\346\234\211]", :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-6709", :google_code=>"FEB39"},
            0x1D9 => {:fallback=>nil, :unicode=>nil, :name=>"BLOWFISH", :google_code=>"FE1D9"},
            0xB2E => {:fallback=>"[\347\246\201]", :unicode=>"+1F231", :name=>"SQUARED CJK UNIFIED IDEOGRAPH-7981", :google_code=>"FEB2E"},
            0x1CE => {:fallback=>"[\343\202\265\343\203\253]", :unicode=>nil, :name=>"MONKEY", :google_code=>"FE1CE"},
            0x337 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE", :google_code=>"FE337"},
            0x32B => {:fallback=>nil, :unicode=>nil, :name=>"FACE SAVORING DELICIOUS FOOD", :google_code=>"FE32B"},
            0xB2F => {:fallback=>nil, :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-7A7A", :google_code=>"FEB2F"},
            0x1CF => {:fallback=>"[\343\203\222\343\203\204\343\202\270]", :unicode=>nil, :name=>"SHEEP", :google_code=>"FE1CF"},
            0x338 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY FACE WITH OPEN MOUTH AND RAISED EYEBROWS", :google_code=>"FE338"},
            0xB40 => {:fallback=>"[\346\214\207]", :unicode=>"*1F224", :name=>"SQUARED CJK UNIFIED IDEOGRAPH-6307", :google_code=>"FEB40"},
            0x1E0 => {:fallback=>nil, :unicode=>nil, :name=>"PIG NOSE", :google_code=>"FE1E0"},
            0x32C => {:fallback=>nil, :unicode=>nil, :name=>"FACE THROWING A KISS", :google_code=>"FE32C"},
            0x339 => {:fallback=>nil, :unicode=>nil, :name=>"CRYING FACE", :google_code=>"FE339"},
            0xB41 => {:fallback=>"[\345\226\266]", :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-55B6", :google_code=>"FEB41"},
            0x1E1 => {:fallback=>"[\343\203\237\343\203\204\343\203\220\343\203\201]", :unicode=>nil, :name=>"HONEYBEE", :google_code=>"FE1E1"},
            0x32D => {:fallback=>nil, :unicode=>nil, :name=>"FACE KISSING", :google_code=>"FE32D"},
            0x1E2 => {:fallback=>"[\343\201\246\343\202\223\343\201\250\343\201\206\350\231\253]", :unicode=>nil, :name=>"LADYBUG", :google_code=>"FE1E2"},
            0x32E => {:fallback=>"[\351\242\250\351\202\252\343\201\262\343\201\215]", :unicode=>nil, :name=>"FACE WITH MASK", :google_code=>"FE32E"},
            0xB42 => {:fallback=>"[TOP]", :unicode=>nil, :name=>"TOP WITH UPWARD SIGN", :google_code=>"FEB42"},
            0x1E3 => {:fallback=>"[\343\202\253\343\203\213]", :unicode=>nil, :name=>"CRAB", :google_code=>"FE1E3"},
            0x32F => {:fallback=>nil, :unicode=>nil, :name=>"FLUSHED FACE", :google_code=>"FE32F"},
            0xB43 => {:fallback=>"[\347\245\235]", :unicode=>"3297", :name=>"CIRCLED IDEOGRAPH CONGRATULATION", :google_code=>"FEB43"},
            0x340 => {:fallback=>nil, :unicode=>nil, :name=>"PENSIVE FACE", :google_code=>"FE340"},
            0xB44 => {:fallback=>nil, :unicode=>"*26E2", :name=>"HEAVY LARGE CIRCLE", :google_code=>"FEB44"},
            0x341 => {:fallback=>nil, :unicode=>nil, :name=>"FACE SCREAMING IN FEAR", :google_code=>"FE341"},
            0xB45 => {:fallback=>"[\303\227]", :unicode=>nil, :name=>"CROSS MARK", :google_code=>"FEB45"},
            0xB3A => {:fallback=>"[\347\204\241]", :unicode=>"*1F22A", :name=>"SQUARED CJK UNIFIED IDEOGRAPH-7121", :google_code=>"FEB3A"},
            0x1DA => {:fallback=>"[\343\202\242\343\203\252]", :unicode=>nil, :name=>"ANT", :google_code=>"FE1DA"},
            0x342 => {:fallback=>nil, :unicode=>nil, :name=>"SLEEPY FACE", :google_code=>"FE342"},
            0xB46 => {:fallback=>"[\303\227]", :unicode=>nil, :name=>"NEGATIVE CROSS MARK", :google_code=>"FEB46"},
            0xB3B => {:fallback=>"[\346\234\210]", :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-6708", :google_code=>"FEB3B"},
            0x1DB => {:fallback=>nil, :unicode=>nil, :name=>"PAW PRINTS", :google_code=>"FE1DB"},
            0x343 => {:fallback=>nil, :unicode=>nil, :name=>"SMIRKING FACE", :google_code=>"FE343"},
            0xB47 => {:fallback=>"[\357\275\211]", :unicode=>"2139", :name=>"INFORMATION SOURCE", :google_code=>"FEB47"},
            0xB3C => {:fallback=>"[\347\224\263]", :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-7533", :google_code=>"FEB3C"},
            0x1DC => {:fallback=>"[\343\202\253\343\203\241]", :unicode=>nil, :name=>"TURTLE", :google_code=>"FE1DC"},
            0x344 => {:fallback=>nil, :unicode=>nil, :name=>"FACE WITH COLD SWEAT", :google_code=>"FE344"},
            0xB48 => {:fallback=>"[\347\246\201\346\255\242]", :unicode=>nil, :name=>"NO ENTRY SIGN", :google_code=>"FEB48"},
            0xB3D => {:fallback=>"[\345\276\227]", :unicode=>"+1F250", :name=>"CIRCLED IDEOGRAPH ADVANTAGE", :google_code=>"FEB3D"},
            0x1DD => {:fallback=>nil, :unicode=>nil, :name=>"HATCHING CHICK", :google_code=>"FE1DD"},
            0x345 => {:fallback=>nil, :unicode=>nil, :name=>"DISAPPOINTED BUT RELIEVED FACE", :google_code=>"FE345"},
            0x33A => {:fallback=>nil, :unicode=>nil, :name=>"LOUDLY CRYING FACE", :google_code=>"FE33A"},
            0xB49 => {:fallback=>"[\343\203\201\343\202\247\343\203\203\343\202\257\343\203\236\343\203\274\343\202\257]", :unicode=>"2714", :name=>"HEAVY CHECK MARK", :google_code=>"FEB49"},
            0xB3E => {:fallback=>"[\345\211\262]", :unicode=>nil, :name=>"SQUARED CJK UNIFIED IDEOGRAPH-5272", :google_code=>"FEB3E"},
            0x1DE => {:fallback=>"[\350\276\260]", :unicode=>nil, :name=>"DRAGON", :google_code=>"FE1DE"},
            0x346 => {:fallback=>nil, :unicode=>nil, :name=>"TIRED FACE", :google_code=>"FE346"},
            0x33B => {:fallback=>nil, :unicode=>nil, :name=>"FEARFUL FACE", :google_code=>"FE33B"},
            0xB3F => {:fallback=>"[\343\202\265\343\203\274\343\203\223\343\202\271]", :unicode=>nil, :name=>"SQUARED KATAKANA SA", :google_code=>"FEB3F"},
            0x1DF => {:fallback=>"[\343\203\221\343\203\263\343\203\200]", :unicode=>nil, :name=>"PANDA", :google_code=>"FE1DF"},
            0x347 => {:fallback=>nil, :unicode=>nil, :name=>"WINKING FACE", :google_code=>"FE347"},
            0x33C => {:fallback=>nil, :unicode=>nil, :name=>"PERSEVERING FACE", :google_code=>"FE33C"},
            0x348 => {:fallback=>nil, :unicode=>nil, :name=>"CAT FACE WITH OPEN MOUTH", :google_code=>"FE348"},
            0xB50 => {:fallback=>"[\345\217\257]", :unicode=>nil, :name=>"CIRCLED IDEOGRAPH ACCEPT", :google_code=>"FEB50"},
            0x33D => {:fallback=>nil, :unicode=>nil, :name=>"POUTING FACE", :google_code=>"FE33D"},
            0x349 => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY CAT FACE WITH GRIN", :google_code=>"FE349"},
            0xB51 => {:fallback=>"[\357\274\213]", :unicode=>"+", :name=>"HEAVY PLUS SIGN", :google_code=>"FEB51"},
            0x33E => {:fallback=>nil, :unicode=>nil, :name=>"RELIEVED FACE", :google_code=>"FE33E"},
            0xB52 => {:fallback=>"[\357\274\215]", :unicode=>nil, :name=>"HEAVY MINUS SIGN", :google_code=>"FEB52"},
            0x33F => {:fallback=>nil, :unicode=>nil, :name=>"CONFOUNDED FACE", :google_code=>"FE33F"},
            0x350 => {:fallback=>nil, :unicode=>nil, :name=>"ANGUISHED CAT FACE", :google_code=>"FE350"},
            0xB53 => {:fallback=>"[\303\227]", :unicode=>"2716", :name=>"HEAVY MULTIPLICATION X", :google_code=>"FEB53"},
            0x351 => {:fallback=>nil, :unicode=>nil, :name=>"FACE WITH NO GOOD GESTURE", :google_code=>"FE351"},
            0xB54 => {:fallback=>"[\303\267]", :unicode=>nil, :name=>"HEAVY DIVISION SIGN", :google_code=>"FEB54"},
            0xB4A => {:fallback=>"[\343\203\201\343\202\247\343\203\203\343\202\257\343\203\236\343\203\274\343\202\257]", :unicode=>"+2705", :name=>"WHITE HEAVY CHECK MARK", :google_code=>"FEB4A"},
            0x352 => {:fallback=>nil, :unicode=>nil, :name=>"FACE WITH OK GESTURE", :google_code=>"FE352"},
            0xB55 => {:fallback=>nil, :unicode=>nil, :name=>"DIAMOND SHAPE WITH A DOT INSIDE", :google_code=>"FEB55"},
            0xB4B => {:fallback=>"[\343\203\252\343\203\263\343\202\257]", :unicode=>"+", :name=>"LINK SYMBOL", :google_code=>"FEB4B"},
            0x353 => {:fallback=>"m(_ _)m", :unicode=>nil, :name=>"PERSON BOWING DEEPLY", :google_code=>"FE353"},
            0xB56 => {:fallback=>nil, :unicode=>nil, :name=>"ELECTRIC LIGHT BULB", :google_code=>"FEB56"},
            0xB4C => {:fallback=>nil, :unicode=>"2003", :name=>"EM SPACE", :google_code=>"FEB4C"},
            0x354 => {:fallback=>"(/_\357\274\274)", :unicode=>nil, :name=>"SEE NO EVIL MONKEY", :google_code=>"FE354"},
            0xB57 => {:fallback=>nil, :unicode=>nil, :name=>"ANGER SIGN", :google_code=>"FEB57"},
            0xB4D => {:fallback=>nil, :unicode=>"2002", :name=>"EN SPACE", :google_code=>"FEB4D"},
            0x355 => {:fallback=>"(\343\203\273\303\227\343\203\273)", :unicode=>nil, :name=>"SPEAK NO EVIL MONKEY", :google_code=>"FE355"},
            0xB58 => {:fallback=>nil, :unicode=>nil, :name=>"BOMB", :google_code=>"FEB58"},
            0xB4E => {:fallback=>nil, :unicode=>"2005", :name=>"FOUR-PER-EM SPACE", :google_code=>"FEB4E"},
            0x356 => {:fallback=>"|(\343\203\273\303\227\343\203\273)|", :unicode=>nil, :name=>"HEAR NO EVIL MONKEY", :google_code=>"FE356"},
            0x34A => {:fallback=>nil, :unicode=>nil, :name=>"HAPPY AND CRYING CAT FACE", :google_code=>"FE34A"},
            0xB59 => {:fallback=>nil, :unicode=>nil, :name=>"SLEEPING SIGN", :google_code=>"FEB59"},
            0xB4F => {:fallback=>"[SOS]", :unicode=>nil, :name=>"SOS SIGN", :google_code=>"FEB4F"},
            0x357 => {:fallback=>"(^-^)/", :unicode=>nil, :name=>"PERSON RAISING ONE HAND", :google_code=>"FE357"},
            0x34B => {:fallback=>nil, :unicode=>nil, :name=>"CAT FACE KISSING", :google_code=>"FE34B"},
            0x358 => {:fallback=>"\357\274\274(^o^)\357\274\217", :unicode=>nil, :name=>"PERSON RAISING BOTH HANDS IN CHEERS", :google_code=>"FE358"},
            0xB60 => {:fallback=>nil, :unicode=>nil, :name=>"SPARKLES", :google_code=>"FEB60"},
            0x34C => {:fallback=>nil, :unicode=>nil, :name=>"CAT FACE WITH HEART SHAPED EYES", :google_code=>"FE34C"},
            0x359 => {:fallback=>nil, :unicode=>nil, :name=>"PERSON FROWNING", :google_code=>"FE359"},
            0xB61 => {:fallback=>nil, :unicode=>"2734", :name=>"EIGHT POINTED BLACK STAR", :google_code=>"FEB61"},
            0x34D => {:fallback=>nil, :unicode=>nil, :name=>"CRYING CAT FACE", :google_code=>"FE34D"},
            0xB62 => {:fallback=>nil, :unicode=>"2733", :name=>"EIGHT SPOKED ASTERISK", :google_code=>"FEB62"},
            0x34E => {:fallback=>nil, :unicode=>nil, :name=>"POUTING CAT FACE", :google_code=>"FE34E"},
            0xB63 => {:fallback=>nil, :unicode=>nil, :name=>"LARGE CIRCLE-1", :google_code=>"FEB63"},
            0x34F => {:fallback=>nil, :unicode=>nil, :name=>"CAT FACE WITH TIGHTLY CLOSED LIPS", :google_code=>"FE34F"},
            0x360 => {:fallback=>"[\343\202\204\343\201\243\343\201\237\343\203\274]", :unicode=>nil, :name=>"BOUNCING HAPPY", :google_code=>"FE360"},
            0xB64 => {:fallback=>nil, :unicode=>nil, :name=>"LARGE CIRCLE-2", :google_code=>"FEB64"},
            0x361 => {:fallback=>"[\343\202\257\343\203\251\343\202\257\343\203\251]", :unicode=>nil, :name=>"FACE WITH ROLLING EYES", :google_code=>"FE361"},
            0xB65 => {:fallback=>nil, :unicode=>"26AA", :name=>"MEDIUM WHITE CIRCLE", :google_code=>"FEB65"},
            0xB5A => {:fallback=>"[\343\203\211\343\203\263\343\203\203]", :unicode=>nil, :name=>"COLLISION SYMBOL", :google_code=>"FEB5A"},
            0x362 => {:fallback=>"[\343\203\240\343\203\240\343\203\240]", :unicode=>nil, :name=>"FACE WITH SLANTED MOUTH", :google_code=>"FE362"},
            0xB66 => {:fallback=>nil, :unicode=>"26AB", :name=>"MEDIUM BLACK CIRCLE", :google_code=>"FEB66"},
            0xB5B => {:fallback=>nil, :unicode=>nil, :name=>"SPLASHING SWEAT", :google_code=>"FEB5B"},
            0x363 => {:fallback=>"[\343\202\250\343\203\203?]", :unicode=>nil, :name=>"FACE WITH UNBALANCED EYES", :google_code=>"FE363"},
            0xB67 => {:fallback=>nil, :unicode=>nil, :name=>"WHITE ROUNDED SQUARE", :google_code=>"FEB67"},
            0xB5C => {:fallback=>nil, :unicode=>nil, :name=>"DRIP", :google_code=>"FEB5C"},
            0x364 => {:fallback=>"[\351\200\206\347\253\213\343\201\241]", :unicode=>nil, :name=>"UPSIDE DOWN FACE", :google_code=>"FE364"},
            0x35A => {:fallback=>nil, :unicode=>nil, :name=>"PERSON WITH POUTING FACE", :google_code=>"FE35A"},
            0xB68 => {:fallback=>"[\342\230\206]", :unicode=>"2B50", :name=>"WHITE MEDIUM STAR", :google_code=>"FEB68"},
            0xB5D => {:fallback=>nil, :unicode=>nil, :name=>"DASH SYMBOL", :google_code=>"FEB5D"},
            0x365 => {:fallback=>"[\346\200\252\346\210\221\343\202\222\343\201\227\343\201\237\351\241\224]", :unicode=>nil, :name=>"INJURED FACE", :google_code=>"FE365"},
            0xB69 => {:fallback=>"[\342\230\206]", :unicode=>nil, :name=>"GLOWING STAR", :google_code=>"FEB69"},
            0xB5E => {:fallback=>"[\345\212\233\343\201\223\343\201\266]", :unicode=>nil, :name=>"FLEXED BICEP", :google_code=>"FEB5E"},
            0x366 => {:fallback=>"[\345\277\203\351\205\215\343\201\227\343\201\237\351\241\224]", :unicode=>nil, :name=>"NERVOUS FACE", :google_code=>"FE366"},
            0x35B => {:fallback=>"(>\344\272\272<)", :unicode=>nil, :name=>"PERSON WITH FOLDED HANDS", :google_code=>"FE35B"},
            0xB5F => {:fallback=>"[\343\202\257\343\203\251\343\202\257\343\203\251]", :unicode=>nil, :name=>"DIZZY SYMBOL", :google_code=>"FEB5F"},
            0x367 => {:fallback=>"[\345\220\214\346\203\205\343\201\227\343\201\237\351\241\224]", :unicode=>nil, :name=>"SYMPATHETIC FACE", :google_code=>"FE367"},
            0xB70 => {:fallback=>"\342\226\240", :unicode=>"25FE", :name=>"BLACK MEDIUM SMALL SQUARE", :google_code=>"FEB70"},
            0x35C => {:fallback=>"B-)", :unicode=>nil, :name=>"COOL FACE", :google_code=>"FE35C"},
            0x368 => {:fallback=>"[\347\264\260\343\201\204\351\241\224]", :unicode=>nil, :name=>"THIN FACE", :google_code=>"FE368"},
            0xB71 => {:fallback=>"\342\226\240", :unicode=>"25FB", :name=>"WHITE MEDIUM SQUARE", :google_code=>"FEB71"},
            0x35D => {:fallback=>"\357\274\274(^-^)\357\274\217", :unicode=>nil, :name=>"HUG FACE", :google_code=>"FE35D"},
            0x369 => {:fallback=>"[\343\203\255\343\203\234\343\203\203\343\203\210]", :unicode=>nil, :name=>"ROBOT", :google_code=>"FE369"},
            0xB72 => {:fallback=>"\342\226\240", :unicode=>"25FC", :name=>"BLACK MEDIUM SQUARE", :google_code=>"FEB72"},
            0x35E => {:fallback=>"8-|", :unicode=>nil, :name=>"GEEK", :google_code=>"FE35E"},
            0x35F => {:fallback=>"[\350\200\203\343\201\210\344\270\255]", :unicode=>nil, :name=>"THINKING", :google_code=>"FE35F"},
            0xB73 => {:fallback=>"\342\227\206", :unicode=>nil, :name=>"LARGE DIAMOND-1", :google_code=>"FEB73"},
            0xB74 => {:fallback=>"\342\227\206", :unicode=>nil, :name=>"LARGE DIAMOND-2", :google_code=>"FEB74"},
            0xEA0 => {:fallback=>"[Google]", :unicode=>nil, :name=>"GOOGLE", :google_code=>"FEEA0"},
            0xB6A => {:fallback=>"\342\230\206\345\275\241", :unicode=>nil, :name=>"SHOOTING STAR", :google_code=>"FEB6A"},
            0xB75 => {:fallback=>"\342\227\206", :unicode=>nil, :name=>"SMALL DIAMOND-1", :google_code=>"FEB75"},
            0xB6B => {:fallback=>"\342\226\240", :unicode=>"2B1C", :name=>"WHITE LARGE SQUARE", :google_code=>"FEB6B"},
            0xB76 => {:fallback=>"\342\227\206", :unicode=>nil, :name=>"SMALL DIAMOND-2", :google_code=>"FEB76"},
            0xB6C => {:fallback=>"\342\226\240", :unicode=>"2B1B", :name=>"BLACK LARGE SQUARE", :google_code=>"FEB6C"},
            0x7D0 => {:fallback=>nil, :unicode=>nil, :name=>"RUNNING SHIRT WITH SASH", :google_code=>"FE7D0"},
            0xB77 => {:fallback=>nil, :unicode=>"2747", :name=>"SPARKLE", :google_code=>"FEB77"},
            0xB6D => {:fallback=>"\342\226\240", :unicode=>"25AB", :name=>"WHITE SMALL SQUARE", :google_code=>"FEB6D"},
            0x7D1 => {:fallback=>nil, :unicode=>"*26BE", :name=>"BASEBALL", :google_code=>"FE7D1"},
            0xB78 => {:fallback=>"\342\226\262", :unicode=>"+", :name=>"UP-POINTING TRIANGLE-1", :google_code=>"FEB78"},
            0xB6E => {:fallback=>"\342\226\240", :unicode=>"25AA", :name=>"BLACK SMALL SQUARE", :google_code=>"FEB6E"},
            0x7D2 => {:fallback=>nil, :unicode=>"*26F3", :name=>"FLAG IN HOLE", :google_code=>"FE7D2"},
            0xB79 => {:fallback=>"\342\226\274", :unicode=>nil, :name=>"DOWN-POINTING TRIANGLE-1", :google_code=>"FEB79"},
            0xB6F => {:fallback=>"\342\226\240", :unicode=>"25FD", :name=>"WHITE MEDIUM SMALL SQUARE", :google_code=>"FEB6F"},
            0x7D3 => {:fallback=>nil, :unicode=>nil, :name=>"TENNIS", :google_code=>"FE7D3"},
            0x7D4 => {:fallback=>nil, :unicode=>"*26BD", :name=>"SOCCER BALL", :google_code=>"FE7D4"},
            0xB80 => {:fallback=>"[ABC]", :unicode=>nil, :name=>"LATIN LETTERS INPUT SYMBOL", :google_code=>"FEB80"},
            0x7D5 => {:fallback=>nil, :unicode=>nil, :name=>"SKIING", :google_code=>"FE7D5"},
            0xB81 => {:fallback=>nil, :unicode=>nil, :name=>"IDENTIFICATION SIGN", :google_code=>"FEB81"},
            0x800 => {:fallback=>nil, :unicode=>nil, :name=>"MICROPHONE", :google_code=>"FE800"},
            0x7D6 => {:fallback=>nil, :unicode=>nil, :name=>"BASKETBALL", :google_code=>"FE7D6"},
            0xB82 => {:fallback=>nil, :unicode=>nil, :name=>"KEY", :google_code=>"FEB82"},
            0x801 => {:fallback=>nil, :unicode=>nil, :name=>"MOVIES", :google_code=>"FE801"},
            0x7D7 => {:fallback=>nil, :unicode=>nil, :name=>"CHECKERED FLAG", :google_code=>"FE7D7"},
            0xB83 => {:fallback=>"\342\206\220\342\224\230", :unicode=>"21A9", :name=>"LEFTWARDS ARROW WITH HOOK", :google_code=>"FEB83"},
            0x802 => {:fallback=>nil, :unicode=>nil, :name=>"MOVIE THEATER", :google_code=>"FE802"},
            0x7D8 => {:fallback=>"[\343\202\271\343\203\216\343\203\234]", :unicode=>nil, :name=>"SNOWBOARDER", :google_code=>"FE7D8"},
            0xB84 => {:fallback=>"[CL]", :unicode=>nil, :name=>"CLEAR SIGN", :google_code=>"FEB84"},
            0x803 => {:fallback=>nil, :unicode=>nil, :name=>"HEADPHONE", :google_code=>"FE803"},
            0x7D9 => {:fallback=>nil, :unicode=>nil, :name=>"RUNNER", :google_code=>"FE7D9"},
            0xB85 => {:fallback=>nil, :unicode=>nil, :name=>"MAGNIFYING GLASS", :google_code=>"FEB85"},
            0x804 => {:fallback=>nil, :unicode=>nil, :name=>"ART", :google_code=>"FE804"},
            0x805 => {:fallback=>nil, :unicode=>nil, :name=>"TOP HAT", :google_code=>"FE805"},
            0xB7A => {:fallback=>"[\350\212\261\344\270\270]", :unicode=>nil, :name=>"WHITE FLOWER", :google_code=>"FEB7A"},
            0xB86 => {:fallback=>nil, :unicode=>nil, :name=>"LOCK", :google_code=>"FEB86"},
            0x806 => {:fallback=>"[\343\202\244\343\203\231\343\203\263\343\203\210]", :unicode=>nil, :name=>"EVENT", :google_code=>"FE806"},
            0xB7B => {:fallback=>"[100\347\202\271]", :unicode=>nil, :name=>"HUNDRED POINTS SYMBOL", :google_code=>"FEB7B"},
            0x7E0 => {:fallback=>nil, :unicode=>nil, :name=>"SUBWAY", :google_code=>"FE7E0"},
            0xB87 => {:fallback=>nil, :unicode=>nil, :name=>"OPEN LOCK", :google_code=>"FEB87"},
            0x807 => {:fallback=>nil, :unicode=>nil, :name=>"TICKET", :google_code=>"FE807"},
            0xB7C => {:fallback=>"[ABCD]", :unicode=>"+1F541", :name=>"LATIN CAPITAL LETTERS INPUT SYMBOL", :google_code=>"FEB7C"},
            0x7E1 => {:fallback=>nil, :unicode=>"24C2", :name=>"CIRCLED LATIN CAPITAL LETTER M", :google_code=>"FE7E1"},
            0xB88 => {:fallback=>"\342\224\224\342\206\222", :unicode=>"21AA", :name=>"RIGHTWARDS ARROW WITH HOOK", :google_code=>"FEB88"},
            0xB7D => {:fallback=>"[abcd]", :unicode=>nil, :name=>"LATIN SMALL LETTERS INPUT SYMBOL", :google_code=>"FEB7D"},
            0xB89 => {:fallback=>"[\343\202\252\343\203\274\343\203\227\343\203\263\343\202\246\343\202\247\343\203\226]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-48", :google_code=>"FEB89"},
            0x7E2 => {:fallback=>nil, :unicode=>nil, :name=>"HIGH-SPEED TRAIN", :google_code=>"FE7E2"},
            0x808 => {:fallback=>nil, :unicode=>nil, :name=>"MOVIE SHOOTING CLAPBOARD", :google_code=>"FE808"},
            0xB7E => {:fallback=>"[1234]", :unicode=>nil, :name=>"NUMBERS INPUT SYMBOL", :google_code=>"FEB7E"},
            0x7E3 => {:fallback=>nil, :unicode=>nil, :name=>"HIGH-SPEED TRAIN WITH BULLET NOSE", :google_code=>"FE7E3"},
            0x809 => {:fallback=>"[\346\274\224\345\212\207]", :unicode=>nil, :name=>"PERFORMING ARTS", :google_code=>"FE809"},
            0xB7F => {:fallback=>"[\350\250\230\345\217\267]", :unicode=>nil, :name=>"SYMBOLS INPUT SYMBOL", :google_code=>"FEB7F"},
            0x7E4 => {:fallback=>nil, :unicode=>nil, :name=>"CAR", :google_code=>"FE7E4"},
            0xB90 => {:fallback=>nil, :unicode=>nil, :name=>"LOCK WITH INK PEN", :google_code=>"FEB90"},
            0x7E5 => {:fallback=>nil, :unicode=>nil, :name=>"RECREATIONAL VEHICLE", :google_code=>"FE7E5"},
            0xB91 => {:fallback=>"\342\206\221\342\206\223", :unicode=>nil, :name=>"DOUBLE CLOCKWISE OPEN CIRCLE ARROWS", :google_code=>"FEB91"},
            0x7DA => {:fallback=>nil, :unicode=>nil, :name=>"SURFER", :google_code=>"FE7DA"},
            0x810 => {:fallback=>"[\343\203\234\343\203\274\343\203\252\343\203\263\343\202\260]", :unicode=>nil, :name=>"BOWLING", :google_code=>"FE810"},
            0x7E6 => {:fallback=>nil, :unicode=>nil, :name=>"BUS", :google_code=>"FE7E6"},
            0xB92 => {:fallback=>nil, :unicode=>nil, :name=>"EMAIL SIGN", :google_code=>"FEB92"},
            0x7DB => {:fallback=>"[\343\203\210\343\203\255\343\203\225\343\202\243\343\203\274]", :unicode=>nil, :name=>"TROPHY", :google_code=>"FE7DB"},
            0x811 => {:fallback=>"[\350\212\261\346\234\255]", :unicode=>nil, :name=>"FLOWER PLAYING CARDS", :google_code=>"FE811"},
            0x7E7 => {:fallback=>"[\343\203\220\343\202\271\345\201\234]", :unicode=>nil, :name=>"BUS STOP", :google_code=>"FE7E7"},
            0xB93 => {:fallback=>nil, :unicode=>"+270A", :name=>"RAISED FIST", :google_code=>"FEB93"},
            0x7DC => {:fallback=>nil, :unicode=>nil, :name=>"HORSE RACING", :google_code=>"FE7DC"},
            0x812 => {:fallback=>"[\343\202\270\343\203\247\343\203\274\343\202\253\343\203\274]", :unicode=>nil, :name=>"JOKER", :google_code=>"FE812"},
            0x7E8 => {:fallback=>nil, :unicode=>nil, :name=>"SHIP", :google_code=>"FE7E8"},
            0xB94 => {:fallback=>nil, :unicode=>"270C", :name=>"VICTORY HAND", :google_code=>"FEB94"},
            0x7DD => {:fallback=>"[\343\203\225\343\203\203\343\203\210\343\203\234\343\203\274\343\203\253]", :unicode=>nil, :name=>"AMERICAN FOOTBALL", :google_code=>"FE7DD"},
            0x813 => {:fallback=>nil, :unicode=>nil, :name=>"MUSICAL NOTE", :google_code=>"FE813"},
            0x7E9 => {:fallback=>nil, :unicode=>"2708", :name=>"AIRPLANE", :google_code=>"FE7E9"},
            0xB95 => {:fallback=>nil, :unicode=>nil, :name=>"RAISED HAND", :google_code=>"FEB95"},
            0x7DE => {:fallback=>"[\346\260\264\346\263\263]", :unicode=>nil, :name=>"SWIMMER", :google_code=>"FE7DE"},
            0x814 => {:fallback=>nil, :unicode=>nil, :name=>"MULTIPLE MUSICAL NOTES", :google_code=>"FE814"},
            0xB96 => {:fallback=>nil, :unicode=>"+", :name=>"FISTED HAND", :google_code=>"FEB96"},
            0x7DF => {:fallback=>nil, :unicode=>nil, :name=>"TRAIN", :google_code=>"FE7DF"},
            0x815 => {:fallback=>nil, :unicode=>nil, :name=>"SAXOPHONE", :google_code=>"FE815"},
            0xB8A => {:fallback=>nil, :unicode=>nil, :name=>"CLOSED LOCK WITH KEY", :google_code=>"FEB8A"},
            0x816 => {:fallback=>"[\343\202\256\343\202\277\343\203\274]", :unicode=>nil, :name=>"GUITAR", :google_code=>"FE816"},
            0xB8B => {:fallback=>"[\343\203\201\343\202\247\343\203\203\343\202\257\343\203\236\343\203\274\343\202\257]", :unicode=>"2611", :name=>"BALLOT BOX WITH CHECK", :google_code=>"FEB8B"},
            0x80A => {:fallback=>"[\343\202\262\343\203\274\343\203\240]", :unicode=>nil, :name=>"VIDEO GAME", :google_code=>"FE80A"},
            0xB97 => {:fallback=>nil, :unicode=>nil, :name=>"THUMBS UP SIGN", :google_code=>"FEB97"},
            0x817 => {:fallback=>"[\343\203\224\343\202\242\343\203\216]", :unicode=>nil, :name=>"MUSICAL KEYBOARD", :google_code=>"FE817"},
            0xB8C => {:fallback=>"[\343\203\251\343\202\270\343\202\252\343\203\234\343\202\277\343\203\263]", :unicode=>nil, :name=>"RADIO BUTTON", :google_code=>"FEB8C"},
            0x7F0 => {:fallback=>nil, :unicode=>nil, :name=>"WALKER", :google_code=>"FE7F0"},
            0x80B => {:fallback=>"[\351\272\273\351\233\200]", :unicode=>"1F004", :name=>"MAHJONG TILE RED DRAGON", :google_code=>"FE80B"},
            0xB98 => {:fallback=>"[\344\272\272\345\267\256\343\201\227\346\214\207]", :unicode=>"261D", :name=>"WHITE UP POINTING INDEX", :google_code=>"FEB98"},
            0x818 => {:fallback=>"[\343\203\210\343\203\251\343\203\263\343\203\232\343\203\203\343\203\210]", :unicode=>nil, :name=>"TRUMPET", :google_code=>"FE818"},
            0xB8D => {:fallback=>nil, :unicode=>nil, :name=>"RIGHT-POINTING MAGNIFYING GLASS", :google_code=>"FEB8D"},
            0x7F1 => {:fallback=>"[\343\203\210\343\203\251\343\203\203\343\202\257]", :unicode=>nil, :name=>"TRUCK", :google_code=>"FE7F1"},
            0x80C => {:fallback=>"[\347\232\204\344\270\255]", :unicode=>nil, :name=>"BULLS EYE", :google_code=>"FE80C"},
            0xB99 => {:fallback=>"[\342\206\221]", :unicode=>nil, :name=>"WHITE UP POINTING BACKHAND INDEX", :google_code=>"FEB99"},
            0xB8E => {:fallback=>"[\342\206\220BACK]", :unicode=>nil, :name=>"LEFTWARDS ARROW WITH LETTER BACK", :google_code=>"FEB8E"},
            0x000 => {:fallback=>nil, :unicode=>"2600", :name=>"BLACK SUN WITH RAYS", :google_code=>"FE000"},
            0x7F2 => {:fallback=>"[\346\266\210\351\230\262\350\273\212]", :unicode=>nil, :name=>"FIRE ENGINE", :google_code=>"FE7F2"},
            0x80D => {:fallback=>"[777]", :unicode=>nil, :name=>"SLOT MACHINE", :google_code=>"FE80D"},
            0x819 => {:fallback=>"[\343\203\220\343\202\244\343\202\252\343\203\252\343\203\263]", :unicode=>nil, :name=>"VIOLIN", :google_code=>"FE819"},
            0xB8F => {:fallback=>"[\343\203\226\343\203\203\343\202\257\343\203\236\343\203\274\343\202\257]", :unicode=>nil, :name=>"BOOKMARK", :google_code=>"FEB8F"},
            0x001 => {:fallback=>nil, :unicode=>"2601", :name=>"CLOUD", :google_code=>"FE001"},
            0x7F3 => {:fallback=>"[\346\225\221\346\200\245\350\273\212]", :unicode=>nil, :name=>"AMBULANCE", :google_code=>"FE7F3"},
            0x80E => {:fallback=>"[\343\203\223\343\203\252\343\203\244\343\203\274\343\203\211]", :unicode=>nil, :name=>"BILLIARDS", :google_code=>"FE80E"},
            0x002 => {:fallback=>nil, :unicode=>"2614", :name=>"UMBRELLA WITH RAIN DROPS", :google_code=>"FE002"},
            0x7F4 => {:fallback=>"[\343\203\221\343\203\210\343\202\253\343\203\274]", :unicode=>nil, :name=>"POLICE CAR", :google_code=>"FE7F4"},
            0x80F => {:fallback=>"[\343\202\265\343\202\244\343\202\263\343\203\255]", :unicode=>nil, :name=>"GAME DIE", :google_code=>"FE80F"},
            0x820 => {:fallback=>"[\343\203\223\343\203\207\343\202\252]", :unicode=>nil, :name=>"VIDEO TAPE", :google_code=>"FE820"},
            0x003 => {:fallback=>nil, :unicode=>"*26C4", :name=>"SNOWMAN WITHOUT SNOW", :google_code=>"FE003"},
            0x7F5 => {:fallback=>nil, :unicode=>"*26FD", :name=>"FUEL PUMP", :google_code=>"FE7F5"},
            0x7EA => {:fallback=>nil, :unicode=>"*26F5", :name=>"SAILBOAT", :google_code=>"FE7EA"},
            0x821 => {:fallback=>"[\343\202\271\343\203\224\343\203\274\343\202\253]", :unicode=>nil, :name=>"SPEAKER", :google_code=>"FE821"},
            0x004 => {:fallback=>nil, :unicode=>"26A1", :name=>"HIGH VOLTAGE SIGN", :google_code=>"FE004"},
            0x7F6 => {:fallback=>nil, :unicode=>"*1F17F", :name=>"WHITE ON BLACK SQUARED LATIN CAPITAL LETTER P", :google_code=>"FE7F6"},
            0x7EB => {:fallback=>nil, :unicode=>nil, :name=>"BICYCLE", :google_code=>"FE7EB"},
            0x822 => {:fallback=>"[\346\226\260\350\201\236]", :unicode=>nil, :name=>"NEWSPAPER", :google_code=>"FE822"},
            0x005 => {:fallback=>nil, :unicode=>nil, :name=>"CYCLONE", :google_code=>"FE005"},
            0x7F7 => {:fallback=>nil, :unicode=>nil, :name=>"TRAFFIC LIGHT", :google_code=>"FE7F7"},
            0x7EC => {:fallback=>"[\351\247\205]", :unicode=>nil, :name=>"STATION", :google_code=>"FE7EC"},
            0x823 => {:fallback=>nil, :unicode=>nil, :name=>"KISS MARK", :google_code=>"FE823"},
            0x006 => {:fallback=>"[\351\234\247]", :unicode=>nil, :name=>"FOG", :google_code=>"FE006"},
            0x7F8 => {:fallback=>"[\345\267\245\344\272\213\344\270\255]", :unicode=>nil, :name=>"CONSTRUCTION", :google_code=>"FE7F8"},
            0x7ED => {:fallback=>"[\343\203\255\343\202\261\343\203\203\343\203\210]", :unicode=>nil, :name=>"ROCKET", :google_code=>"FE7ED"},
            0x824 => {:fallback=>nil, :unicode=>nil, :name=>"LOVE LETTER", :google_code=>"FE824"},
            0x007 => {:fallback=>nil, :unicode=>nil, :name=>"CLOSED UMBRELLA", :google_code=>"FE007"},
            0x7F9 => {:fallback=>"[\343\203\221\343\203\210\343\202\253\343\203\274]", :unicode=>nil, :name=>"POLICE CARS REVOLVING LIGHT", :google_code=>"FE7F9"},
            0x7EE => {:fallback=>nil, :unicode=>nil, :name=>"SPEEDBOAT", :google_code=>"FE7EE"},
            0x825 => {:fallback=>nil, :unicode=>nil, :name=>"RING", :google_code=>"FE825"},
            0xB9A => {:fallback=>"[\342\206\223]", :unicode=>nil, :name=>"WHITE DOWN POINTING BACKHAND INDEX", :google_code=>"FEB9A"},
            0x008 => {:fallback=>nil, :unicode=>nil, :name=>"NIGHT WITH STARS", :google_code=>"FE008"},
            0x7EF => {:fallback=>nil, :unicode=>nil, :name=>"TAXI", :google_code=>"FE7EF"},
            0x826 => {:fallback=>nil, :unicode=>nil, :name=>"GEM STONE", :google_code=>"FE826"},
            0xB9B => {:fallback=>"[\342\206\220]", :unicode=>nil, :name=>"WHITE LEFT POINTING BACKHAND INDEX", :google_code=>"FEB9B"},
            0x81A => {:fallback=>nil, :unicode=>nil, :name=>"MUSICAL SCORE", :google_code=>"FE81A"},
            0x009 => {:fallback=>nil, :unicode=>nil, :name=>"SUNRISE OVER MOUNTAINS", :google_code=>"FE009"},
            0x827 => {:fallback=>nil, :unicode=>nil, :name=>"KISS", :google_code=>"FE827"},
            0xB9C => {:fallback=>"[\342\206\222]", :unicode=>nil, :name=>"WHITE RIGHT POINTING BACKHAND INDEX", :google_code=>"FEB9C"},
            0x81B => {:fallback=>"[\343\202\260\343\203\251\343\203\225]", :unicode=>"303D", :name=>"PART ALTERNATION MARK", :google_code=>"FE81B"},
            0x828 => {:fallback=>"[\350\212\261\346\235\237]", :unicode=>nil, :name=>"BOUQUET", :google_code=>"FE828"},
            0xB9D => {:fallback=>nil, :unicode=>nil, :name=>"WAVING HAND", :google_code=>"FEB9D"},
            0x81C => {:fallback=>nil, :unicode=>nil, :name=>"TV", :google_code=>"FE81C"},
            0xB9E => {:fallback=>"[\346\213\215\346\211\213]", :unicode=>nil, :name=>"CLAPPING HANDS", :google_code=>"FEB9E"},
            0x010 => {:fallback=>nil, :unicode=>nil, :name=>"BRIDGE AT NIGHT", :google_code=>"FE010"},
            0x81D => {:fallback=>nil, :unicode=>nil, :name=>"OPTICAL DISK", :google_code=>"FE81D"},
            0x829 => {:fallback=>nil, :unicode=>nil, :name=>"COUPLE WITH HEART", :google_code=>"FE829"},
            0xB9F => {:fallback=>nil, :unicode=>nil, :name=>"OK HAND SIGN", :google_code=>"FEB9F"},
            0x011 => {:fallback=>"\342\227\217", :unicode=>nil, :name=>"NEW MOON", :google_code=>"FE011"},
            0x81E => {:fallback=>nil, :unicode=>nil, :name=>"DVD", :google_code=>"FE81E"},
            0x960 => {:fallback=>nil, :unicode=>nil, :name=>"HAMBURGER", :google_code=>"FE960"},
            0x012 => {:fallback=>nil, :unicode=>nil, :name=>"WAXING MOON", :google_code=>"FE012"},
            0x81F => {:fallback=>"[\343\203\251\343\202\270\343\202\252]", :unicode=>nil, :name=>"RADIO", :google_code=>"FE81F"},
            0x961 => {:fallback=>nil, :unicode=>nil, :name=>"RICE BALL", :google_code=>"FE961"},
            0x013 => {:fallback=>nil, :unicode=>nil, :name=>"HALF MOON", :google_code=>"FE013"},
            0x7FA => {:fallback=>nil, :unicode=>"2668", :name=>"HOT SPRINGS", :google_code=>"FE7FA"},
            0x830 => {:fallback=>nil, :unicode=>"0033+20E3", :name=>"KEYCAP 3", :google_code=>"FE830"},
            0x962 => {:fallback=>nil, :unicode=>nil, :name=>"SHORTCAKE", :google_code=>"FE962"},
            0x014 => {:fallback=>nil, :unicode=>nil, :name=>"CRESCENT MOON", :google_code=>"FE014"},
            0x7FB => {:fallback=>"[\343\202\255\343\203\243\343\203\263\343\203\227]", :unicode=>"*26FA", :name=>"TENT", :google_code=>"FE7FB"},
            0x831 => {:fallback=>nil, :unicode=>"0034+20E3", :name=>"KEYCAP 4", :google_code=>"FE831"},
            0x963 => {:fallback=>nil, :unicode=>nil, :name=>"STEAMING BOWL", :google_code=>"FE963"},
            0x015 => {:fallback=>"\342\227\213", :unicode=>nil, :name=>"FULL MOON", :google_code=>"FE015"},
            0x7FC => {:fallback=>nil, :unicode=>nil, :name=>"CAROUSEL HORSE", :google_code=>"FE7FC"},
            0x832 => {:fallback=>nil, :unicode=>"0035+20E3", :name=>"KEYCAP 5", :google_code=>"FE832"},
            0x964 => {:fallback=>nil, :unicode=>nil, :name=>"BREAD", :google_code=>"FE964"},
            0x016 => {:fallback=>nil, :unicode=>nil, :name=>"HALF MOON WITH FACE", :google_code=>"FE016"},
            0x00A => {:fallback=>nil, :unicode=>nil, :name=>"SUNRISE", :google_code=>"FE00A"},
            0x7FD => {:fallback=>"[\350\246\263\350\246\247\350\273\212]", :unicode=>nil, :name=>"FERRIS WHEEL", :google_code=>"FE7FD"},
            0x833 => {:fallback=>nil, :unicode=>"0036+20E3", :name=>"KEYCAP 6", :google_code=>"FE833"},
            0x965 => {:fallback=>"[\343\203\225\343\203\251\343\202\244\343\203\221\343\203\263]", :unicode=>nil, :name=>"COOKING", :google_code=>"FE965"},
            0x017 => {:fallback=>"[\343\201\212\346\234\210\350\246\213]", :unicode=>nil, :name=>"MOON VIEWING CEREMONY", :google_code=>"FE017"},
            0x00B => {:fallback=>"[\345\244\225\347\204\274\343\201\221]", :unicode=>nil, :name=>"CITYSCAPE AT DUSK", :google_code=>"FE00B"},
            0x7FE => {:fallback=>"[\343\202\270\343\202\247\343\203\203\343\203\210\343\202\263\343\203\274\343\202\271\343\202\277\343\203\274]", :unicode=>nil, :name=>"ROLLER COASTER", :google_code=>"FE7FE"},
            0x834 => {:fallback=>nil, :unicode=>"0037+20E3", :name=>"KEYCAP 7", :google_code=>"FE834"},
            0x966 => {:fallback=>"[\343\202\275\343\203\225\343\203\210\343\202\257\343\203\252\343\203\274\343\203\240]", :unicode=>nil, :name=>"SOFT ICE CREAM", :google_code=>"FE966"},
            0x018 => {:fallback=>"[SOON]", :unicode=>nil, :name=>"SOON WITH RIGHT ARROW ABOVE", :google_code=>"FE018"},
            0x00C => {:fallback=>nil, :unicode=>nil, :name=>"SUNSET OVER BUILDINGS", :google_code=>"FE00C"},
            0x7FF => {:fallback=>nil, :unicode=>nil, :name=>"FISHING", :google_code=>"FE7FF"},
            0x835 => {:fallback=>nil, :unicode=>"0038+20E3", :name=>"KEYCAP 8", :google_code=>"FE835"},
            0x967 => {:fallback=>"[\343\203\235\343\203\206\343\203\210]", :unicode=>nil, :name=>"FRENCH FRIES", :google_code=>"FE967"},
            0x019 => {:fallback=>"[ON]", :unicode=>nil, :name=>"ON WITH DOUBLE POINTING ARROW ABOVE", :google_code=>"FE019"},
            0x00D => {:fallback=>"[\350\231\271]", :unicode=>nil, :name=>"RAINBOW", :google_code=>"FE00D"},
            0x836 => {:fallback=>nil, :unicode=>"0039+20E3", :name=>"KEYCAP 9", :google_code=>"FE836"},
            0x968 => {:fallback=>"[\343\201\240\343\202\223\343\201\224]", :unicode=>nil, :name=>"DUMPLING", :google_code=>"FE968"},
            0x82A => {:fallback=>nil, :unicode=>nil, :name=>"WEDDING", :google_code=>"FE82A"},
            0x82B => {:fallback=>"[\343\203\225\343\203\252\343\203\274\343\203\200\343\202\244\343\203\244\343\203\253]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-65", :google_code=>"FE82B"},
            0x00E => {:fallback=>"[\351\233\252\347\265\220\346\231\266]", :unicode=>"2744", :name=>"SNOWFLAKE", :google_code=>"FE00E"},
            0x837 => {:fallback=>nil, :unicode=>"0030+20E3", :name=>"KEYCAP 0", :google_code=>"FE837"},
            0x969 => {:fallback=>"[\343\201\233\343\202\223\343\201\271\343\201\204]", :unicode=>nil, :name=>"RICE CRACKER", :google_code=>"FE969"},
            0x00F => {:fallback=>nil, :unicode=>"*26C5", :name=>"SUN BEHIND CLOUD", :google_code=>"FE00F"},
            0x838 => {:fallback=>"[\343\203\220\343\203\2523]", :unicode=>nil, :name=>"ANTENNA MARK", :google_code=>"FE838"},
            0x82C => {:fallback=>nil, :unicode=>"0023+20E3", :name=>"HASH KEY", :google_code=>"FE82C"},
            0x82D => {:fallback=>"[Q]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-66", :google_code=>"FE82D"},
            0x839 => {:fallback=>"[\343\203\236\343\203\212\343\203\274\343\203\242\343\203\274\343\203\211]", :unicode=>nil, :name=>"VIBRATION MODE", :google_code=>"FE839"},
            0x020 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE THREE OCLOCK", :google_code=>"FE020"},
            0x970 => {:fallback=>"[\351\215\213]", :unicode=>nil, :name=>"POT OF FOOD", :google_code=>"FE970"},
            0x021 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE FOUR OCLOCK", :google_code=>"FE021"},
            0x82E => {:fallback=>nil, :unicode=>"0031+20E3", :name=>"KEYCAP 1", :google_code=>"FE82E"},
            0x971 => {:fallback=>"[\343\202\253\343\202\255\346\260\267]", :unicode=>nil, :name=>"SHAVED ICE", :google_code=>"FE971"},
            0x022 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE FIVE OCLOCK", :google_code=>"FE022"},
            0x82F => {:fallback=>nil, :unicode=>"0032+20E3", :name=>"KEYCAP 2", :google_code=>"FE82F"},
            0x972 => {:fallback=>"[\350\202\211]", :unicode=>nil, :name=>"MEAT ON BONE", :google_code=>"FE972"},
            0x023 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE SIX OCLOCK", :google_code=>"FE023"},
            0x973 => {:fallback=>"[\343\201\252\343\202\213\343\201\250]", :unicode=>nil, :name=>"FISH CAKE WITH SWIRL DESIGN", :google_code=>"FE973"},
            0x024 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE SEVEN OCLOCK", :google_code=>"FE024"},
            0x974 => {:fallback=>"[\343\202\204\343\201\215\343\201\204\343\202\202]", :unicode=>nil, :name=>"ROASTED SWEET POTATO", :google_code=>"FE974"},
            0x025 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE EIGHT OCLOCK", :google_code=>"FE025"},
            0x975 => {:fallback=>"[\343\203\224\343\202\266]", :unicode=>nil, :name=>"PIZZA", :google_code=>"FE975"},
            0x026 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE NINE OCLOCK", :google_code=>"FE026"},
            0x01A => {:fallback=>"[end]", :unicode=>nil, :name=>"END WITH LEFT ARROW ABOVE", :google_code=>"FE01A"},
            0x976 => {:fallback=>"[\343\203\201\343\202\255\343\203\263]", :unicode=>nil, :name=>"POULTRY LEG", :google_code=>"FE976"},
            0x96A => {:fallback=>nil, :unicode=>nil, :name=>"COOKED RICE", :google_code=>"FE96A"},
            0x027 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE TEN OCLOCK", :google_code=>"FE027"},
            0x01B => {:fallback=>"[\347\240\202\346\231\202\350\250\210]", :unicode=>nil, :name=>"HOURGLASS WITH FLOWING SAND", :google_code=>"FE01B"},
            0x977 => {:fallback=>"[\343\202\242\343\202\244\343\202\271\343\202\257\343\203\252\343\203\274\343\203\240]", :unicode=>nil, :name=>"ICE CREAM", :google_code=>"FE977"},
            0x96B => {:fallback=>"[\343\203\221\343\202\271\343\202\277]", :unicode=>nil, :name=>"SPAGHETTI", :google_code=>"FE96B"},
            0x028 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE ELEVEN OCLOCK", :google_code=>"FE028"},
            0x01C => {:fallback=>"[\347\240\202\346\231\202\350\250\210]", :unicode=>"231B", :name=>"HOURGLASS", :google_code=>"FE01C"},
            0x978 => {:fallback=>"[\343\203\211\343\203\274\343\203\212\343\203\204]", :unicode=>nil, :name=>"DONUT", :google_code=>"FE978"},
            0x83A => {:fallback=>"[\343\202\261\343\203\274\343\202\277\343\202\244OFF]", :unicode=>nil, :name=>"PHONE OFF", :google_code=>"FE83A"},
            0x96C => {:fallback=>"[\343\202\253\343\203\254\343\203\274]", :unicode=>nil, :name=>"CURRY AND RICE", :google_code=>"FE96C"},
            0x029 => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE TWELVE OCLOCK", :google_code=>"FE029"},
            0x01D => {:fallback=>"[\350\205\225\346\231\202\350\250\210]", :unicode=>"231A", :name=>"WATCH", :google_code=>"FE01D"},
            0x979 => {:fallback=>"[\343\202\257\343\203\203\343\202\255\343\203\274]", :unicode=>nil, :name=>"COOKIE", :google_code=>"FE979"},
            0x83B => {:fallback=>"[10]", :unicode=>nil, :name=>"KEYCAP TEN", :google_code=>"FE83B"},
            0x96D => {:fallback=>"[\343\201\212\343\201\247\343\202\223]", :unicode=>nil, :name=>"SEAFOOD CASSEROLE", :google_code=>"FE96D"},
            0x01E => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE ONE OCLOCK", :google_code=>"FE01E"},
            0x83C => {:fallback=>"[PDC]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-49", :google_code=>"FE83C"},
            0x96E => {:fallback=>"[\343\201\231\343\201\227]", :unicode=>nil, :name=>"SUSHI", :google_code=>"FE96E"},
            0x01F => {:fallback=>nil, :unicode=>nil, :name=>"CLOCK FACE TWO OCLOCK", :google_code=>"FE01F"},
            0x030 => {:fallback=>nil, :unicode=>"264D", :name=>"VIRGO", :google_code=>"FE030"},
            0x96F => {:fallback=>"[\345\274\201\345\275\223]", :unicode=>nil, :name=>"LUNCHBOX", :google_code=>"FE96F"},
            0x031 => {:fallback=>nil, :unicode=>"264E", :name=>"LIBRA", :google_code=>"FE031"},
            0x980 => {:fallback=>nil, :unicode=>nil, :name=>"FORK AND KNIFE", :google_code=>"FE980"},
            0x032 => {:fallback=>nil, :unicode=>"264F", :name=>"SCORPIUS", :google_code=>"FE032"},
            0x981 => {:fallback=>nil, :unicode=>"2615", :name=>"HOT BEVERAGE", :google_code=>"FE981"},
            0x033 => {:fallback=>nil, :unicode=>"2650", :name=>"SAGITTARIUS", :google_code=>"FE033"},
            0x982 => {:fallback=>nil, :unicode=>nil, :name=>"COCKTAIL GLASS", :google_code=>"FE982"},
            0x034 => {:fallback=>nil, :unicode=>"2651", :name=>"CAPRICORN", :google_code=>"FE034"},
            0x983 => {:fallback=>nil, :unicode=>nil, :name=>"BEER MUG", :google_code=>"FE983"},
            0x035 => {:fallback=>nil, :unicode=>"2652", :name=>"AQUARIUS", :google_code=>"FE035"},
            0x02A => {:fallback=>nil, :unicode=>"+23E9", :name=>"ALARM CLOCK", :google_code=>"FE02A"},
            0x984 => {:fallback=>nil, :unicode=>nil, :name=>"TEACUP WITHOUT HANDLE", :google_code=>"FE984"},
            0x036 => {:fallback=>nil, :unicode=>"2653", :name=>"PISCES", :google_code=>"FE036"},
            0x985 => {:fallback=>nil, :unicode=>nil, :name=>"SAKE BOTTLE AND CUP", :google_code=>"FE985"},
            0x97A => {:fallback=>"[\343\203\201\343\203\247\343\202\263]", :unicode=>nil, :name=>"CHOCOLATE BAR", :google_code=>"FE97A"},
            0x037 => {:fallback=>"[\350\233\207\344\275\277\345\272\247]", :unicode=>"+", :name=>"OPHIUCHUS", :google_code=>"FE037"},
            0x02B => {:fallback=>nil, :unicode=>"2648", :name=>"ARIES", :google_code=>"FE02B"},
            0x986 => {:fallback=>nil, :unicode=>nil, :name=>"WINE GLASS", :google_code=>"FE986"},
            0x97B => {:fallback=>"[\343\202\255\343\203\243\343\203\263\343\203\207\343\202\243]", :unicode=>nil, :name=>"CANDY", :google_code=>"FE97B"},
            0x038 => {:fallback=>nil, :unicode=>nil, :name=>"WATER WAVE", :google_code=>"FE038"},
            0x02C => {:fallback=>nil, :unicode=>"2649", :name=>"TAURUS", :google_code=>"FE02C"},
            0x987 => {:fallback=>nil, :unicode=>nil, :name=>"CLINKING BEER MUGS", :google_code=>"FE987"},
            0x97C => {:fallback=>"[\343\202\255\343\203\243\343\203\263\343\203\207\343\202\243]", :unicode=>nil, :name=>"LOLLIPOP", :google_code=>"FE97C"},
            0x039 => {:fallback=>"[\345\234\260\347\220\203]", :unicode=>nil, :name=>"EARTH GLOBE", :google_code=>"FE039"},
            0x02D => {:fallback=>nil, :unicode=>"264A", :name=>"GEMINI", :google_code=>"FE02D"},
            0x988 => {:fallback=>nil, :unicode=>nil, :name=>"TROPICAL DRINK", :google_code=>"FE988"},
            0x97D => {:fallback=>"[\343\203\227\343\203\252\343\203\263]", :unicode=>nil, :name=>"CUSTARD", :google_code=>"FE97D"},
            0x02E => {:fallback=>nil, :unicode=>"264B", :name=>"CANCER", :google_code=>"FE02E"},
            0x97E => {:fallback=>"[\343\203\217\343\203\201\343\203\237\343\203\204]", :unicode=>nil, :name=>"HONEY POT", :google_code=>"FE97E"},
            0x02F => {:fallback=>nil, :unicode=>"264C", :name=>"LEO", :google_code=>"FE02F"},
            0x97F => {:fallback=>"[\343\202\250\343\203\223\343\203\225\343\203\251\343\202\244]", :unicode=>nil, :name=>"FRIED SHRIMP", :google_code=>"FE97F"},
            0x040 => {:fallback=>nil, :unicode=>nil, :name=>"CHERRY BLOSSOM", :google_code=>"FE040"},
            0x041 => {:fallback=>"[\343\203\220\343\203\251]", :unicode=>nil, :name=>"ROSE", :google_code=>"FE041"},
            0x042 => {:fallback=>nil, :unicode=>nil, :name=>"FALLEN LEAF", :google_code=>"FE042"},
            0x043 => {:fallback=>nil, :unicode=>nil, :name=>"LEAF FLUTTERING IN WIND", :google_code=>"FE043"},
            0x044 => {:fallback=>"[\350\213\245\350\221\211\343\203\236\343\203\274\343\202\257]", :unicode=>nil, :name=>"JAPANESE SYMBOL FOR BEGINNER", :google_code=>"FE044"},
            0x03A => {:fallback=>"[\347\201\253\345\261\261]", :unicode=>nil, :name=>"VOLCANO", :google_code=>"FE03A"},
            0x045 => {:fallback=>"[\343\203\217\343\202\244\343\203\223\343\202\271\343\202\253\343\202\271]", :unicode=>nil, :name=>"HIBISCUS", :google_code=>"FE045"},
            0x03B => {:fallback=>nil, :unicode=>nil, :name=>"MILKY WAY", :google_code=>"FE03B"},
            0x046 => {:fallback=>"[\343\201\262\343\201\276\343\202\217\343\202\212]", :unicode=>nil, :name=>"SUNFLOWER", :google_code=>"FE046"},
            0x047 => {:fallback=>"[\343\203\223\343\203\274\343\203\201]", :unicode=>nil, :name=>"PALM TREE", :google_code=>"FE047"},
            0x03C => {:fallback=>nil, :unicode=>nil, :name=>"FOUR LEAF CLOVER", :google_code=>"FE03C"},
            0x048 => {:fallback=>"[\343\202\265\343\203\234\343\203\206\343\203\263]", :unicode=>nil, :name=>"CACTUS", :google_code=>"FE048"},
            0x03D => {:fallback=>nil, :unicode=>nil, :name=>"TULIP", :google_code=>"FE03D"},
            0x049 => {:fallback=>nil, :unicode=>nil, :name=>"EAR OF RICE", :google_code=>"FE049"},
            0x03E => {:fallback=>nil, :unicode=>nil, :name=>"SEEDLING", :google_code=>"FE03E"},
            0x03F => {:fallback=>nil, :unicode=>nil, :name=>"MAPLE LEAF", :google_code=>"FE03F"},
            0x050 => {:fallback=>"[\343\203\220\343\203\212\343\203\212]", :unicode=>nil, :name=>"BANANA", :google_code=>"FE050"},
            0x051 => {:fallback=>nil, :unicode=>nil, :name=>"APPLE-1", :google_code=>"FE051"},
            0x052 => {:fallback=>"[\343\201\277\343\201\213\343\202\223]", :unicode=>nil, :name=>"TANGERINE", :google_code=>"FE052"},
            0x053 => {:fallback=>"[\343\202\244\343\203\201\343\202\264]", :unicode=>nil, :name=>"STRAWBERRY", :google_code=>"FE053"},
            0xE10 => {:fallback=>"[i\343\203\242\343\203\274\343\203\211]", :unicode=>"+1F600", :name=>"EMOJI COMPATIBILITY SYMBOL-1", :google_code=>"FEE10"},
            0x4B0 => {:fallback=>nil, :unicode=>nil, :name=>"HOUSE BUILDING", :google_code=>"FE4B0"},
            0x054 => {:fallback=>"[\343\202\271\343\202\244\343\202\253]", :unicode=>nil, :name=>"WATERMELON", :google_code=>"FE054"},
            0xE11 => {:fallback=>"[i\343\203\242\343\203\274\343\203\211]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-2", :google_code=>"FEE11"},
            0x4B1 => {:fallback=>nil, :unicode=>nil, :name=>"HOUSE WITH YARD", :google_code=>"FE4B1"},
            0x055 => {:fallback=>"[\343\203\210\343\203\236\343\203\210]", :unicode=>nil, :name=>"TOMATO", :google_code=>"FE055"},
            0x04A => {:fallback=>"[\343\201\250\343\201\206\343\202\202\343\202\215\343\201\223\343\201\227]", :unicode=>nil, :name=>"CORN", :google_code=>"FE04A"},
            0xE12 => {:fallback=>"[\343\203\211\343\202\263\343\203\242]", :unicode=>nil, :name=>"EMOJI COMPATIBILITY SYMBOL-3", :google_code=>"FEE12"},
            0x4B2 => {:fallback=>nil, :unicode=>nil, :name=>"OFFICE BUILDING", :google_code=>"FE4B2"},
            0x056 => {:fallback=>"[\343\203\212\343\202\271]", :unicode=>nil, :name=>"EGGPLANT", :google_code=>"FE056"},
            0x04B => {:fallback=>"[\343\202\255\343\203\216\343\202\263]", :unicode=>nil, :name=>"MUSHROOM", :google_code=>"FE04B"},
          }

          # 1.8系、1.9系 互換性維持のため
          if RUBY_VERSION >= '1.9.0'
            def EMOJI_TO_EMOJIID.index(val)
              key(val)
            end
          end
          
        end
      end
    end
  end
end

